Class: Aws::VPCLattice::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::VPCLattice::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-vpclattice/client.rb,
sig/client.rbs
Overview
An API client for VPCLattice. To construct a client, you need to configure a :region and :credentials.
client = Aws::VPCLattice::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchUpdateRuleResponseSuccess, _CreateAccessLogSubscriptionResponseSuccess, _CreateListenerResponseSuccess, _CreateResourceConfigurationResponseSuccess, _CreateResourceGatewayResponseSuccess, _CreateRuleResponseSuccess, _CreateServiceNetworkResourceAssociationResponseSuccess, _CreateServiceNetworkResponseSuccess, _CreateServiceNetworkServiceAssociationResponseSuccess, _CreateServiceNetworkVpcAssociationResponseSuccess, _CreateServiceResponseSuccess, _CreateTargetGroupResponseSuccess, _DeleteAccessLogSubscriptionResponseSuccess, _DeleteAuthPolicyResponseSuccess, _DeleteDomainVerificationResponseSuccess, _DeleteListenerResponseSuccess, _DeleteResourceConfigurationResponseSuccess, _DeleteResourceEndpointAssociationResponseSuccess, _DeleteResourceGatewayResponseSuccess, _DeleteResourcePolicyResponseSuccess, _DeleteRuleResponseSuccess, _DeleteServiceNetworkResourceAssociationResponseSuccess, _DeleteServiceNetworkResponseSuccess, _DeleteServiceNetworkServiceAssociationResponseSuccess, _DeleteServiceNetworkVpcAssociationResponseSuccess, _DeleteServiceResponseSuccess, _DeleteTargetGroupResponseSuccess, _DeregisterTargetsResponseSuccess, _GetAccessLogSubscriptionResponseSuccess, _GetAuthPolicyResponseSuccess, _GetDomainVerificationResponseSuccess, _GetListenerResponseSuccess, _GetResourceConfigurationResponseSuccess, _GetResourceGatewayResponseSuccess, _GetResourcePolicyResponseSuccess, _GetRuleResponseSuccess, _GetServiceNetworkResourceAssociationResponseSuccess, _GetServiceNetworkResponseSuccess, _GetServiceNetworkServiceAssociationResponseSuccess, _GetServiceNetworkVpcAssociationResponseSuccess, _GetServiceResponseSuccess, _GetTargetGroupResponseSuccess, _ListAccessLogSubscriptionsResponseSuccess, _ListDomainVerificationsResponseSuccess, _ListListenersResponseSuccess, _ListResourceConfigurationsResponseSuccess, _ListResourceEndpointAssociationsResponseSuccess, _ListResourceGatewaysResponseSuccess, _ListRulesResponseSuccess, _ListServiceNetworkResourceAssociationsResponseSuccess, _ListServiceNetworkServiceAssociationsResponseSuccess, _ListServiceNetworkVpcAssociationsResponseSuccess, _ListServiceNetworkVpcEndpointAssociationsResponseSuccess, _ListServiceNetworksResponseSuccess, _ListServicesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTargetGroupsResponseSuccess, _ListTargetsResponseSuccess, _PutAuthPolicyResponseSuccess, _PutResourcePolicyResponseSuccess, _RegisterTargetsResponseSuccess, _StartDomainVerificationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAccessLogSubscriptionResponseSuccess, _UpdateListenerResponseSuccess, _UpdateResourceConfigurationResponseSuccess, _UpdateResourceGatewayResponseSuccess, _UpdateRuleResponseSuccess, _UpdateServiceNetworkResponseSuccess, _UpdateServiceNetworkVpcAssociationResponseSuccess, _UpdateServiceResponseSuccess, _UpdateTargetGroupResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_update_rule(params = {}) ⇒ Types::BatchUpdateRuleResponse
Updates the listener rules in a batch.
-
#create_access_log_subscription(params = {}) ⇒ Types::CreateAccessLogSubscriptionResponse
Enables access logs to be sent to Amazon CloudWatch, Amazon S3, and Amazon Kinesis Data Firehose.
-
#create_listener(params = {}) ⇒ Types::CreateListenerResponse
Creates a listener for a service.
-
#create_resource_configuration(params = {}) ⇒ Types::CreateResourceConfigurationResponse
Creates a resource configuration.
-
#create_resource_gateway(params = {}) ⇒ Types::CreateResourceGatewayResponse
A resource gateway is a point of ingress into the VPC where a resource resides.
-
#create_rule(params = {}) ⇒ Types::CreateRuleResponse
Creates a listener rule.
-
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates a service.
-
#create_service_network(params = {}) ⇒ Types::CreateServiceNetworkResponse
Creates a service network.
-
#create_service_network_resource_association(params = {}) ⇒ Types::CreateServiceNetworkResourceAssociationResponse
Associates the specified service network with the specified resource configuration.
-
#create_service_network_service_association(params = {}) ⇒ Types::CreateServiceNetworkServiceAssociationResponse
Associates the specified service with the specified service network.
-
#create_service_network_vpc_association(params = {}) ⇒ Types::CreateServiceNetworkVpcAssociationResponse
Associates a VPC with a service network.
-
#create_target_group(params = {}) ⇒ Types::CreateTargetGroupResponse
Creates a target group.
-
#delete_access_log_subscription(params = {}) ⇒ Struct
Deletes the specified access log subscription.
-
#delete_auth_policy(params = {}) ⇒ Struct
Deletes the specified auth policy.
-
#delete_domain_verification(params = {}) ⇒ Struct
Deletes the specified domain verification.
-
#delete_listener(params = {}) ⇒ Struct
Deletes the specified listener.
-
#delete_resource_configuration(params = {}) ⇒ Struct
Deletes the specified resource configuration.
-
#delete_resource_endpoint_association(params = {}) ⇒ Types::DeleteResourceEndpointAssociationResponse
Disassociates the resource configuration from the resource VPC endpoint.
-
#delete_resource_gateway(params = {}) ⇒ Types::DeleteResourceGatewayResponse
Deletes the specified resource gateway.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the specified resource policy.
-
#delete_rule(params = {}) ⇒ Struct
Deletes a listener rule.
-
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Deletes a service.
-
#delete_service_network(params = {}) ⇒ Struct
Deletes a service network.
-
#delete_service_network_resource_association(params = {}) ⇒ Types::DeleteServiceNetworkResourceAssociationResponse
Deletes the association between a service network and a resource configuration.
-
#delete_service_network_service_association(params = {}) ⇒ Types::DeleteServiceNetworkServiceAssociationResponse
Deletes the association between a service and a service network.
-
#delete_service_network_vpc_association(params = {}) ⇒ Types::DeleteServiceNetworkVpcAssociationResponse
Disassociates the VPC from the service network.
-
#delete_target_group(params = {}) ⇒ Types::DeleteTargetGroupResponse
Deletes a target group.
-
#deregister_targets(params = {}) ⇒ Types::DeregisterTargetsResponse
Deregisters the specified targets from the specified target group.
-
#get_access_log_subscription(params = {}) ⇒ Types::GetAccessLogSubscriptionResponse
Retrieves information about the specified access log subscription.
-
#get_auth_policy(params = {}) ⇒ Types::GetAuthPolicyResponse
Retrieves information about the auth policy for the specified service or service network.
-
#get_domain_verification(params = {}) ⇒ Types::GetDomainVerificationResponse
Retrieves information about a domain verification.ß.
-
#get_listener(params = {}) ⇒ Types::GetListenerResponse
Retrieves information about the specified listener for the specified service.
-
#get_resource_configuration(params = {}) ⇒ Types::GetResourceConfigurationResponse
Retrieves information about the specified resource configuration.
-
#get_resource_gateway(params = {}) ⇒ Types::GetResourceGatewayResponse
Retrieves information about the specified resource gateway.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Retrieves information about the specified resource policy.
-
#get_rule(params = {}) ⇒ Types::GetRuleResponse
Retrieves information about the specified listener rules.
-
#get_service(params = {}) ⇒ Types::GetServiceResponse
Retrieves information about the specified service.
-
#get_service_network(params = {}) ⇒ Types::GetServiceNetworkResponse
Retrieves information about the specified service network.
-
#get_service_network_resource_association(params = {}) ⇒ Types::GetServiceNetworkResourceAssociationResponse
Retrieves information about the specified association between a service network and a resource configuration.
-
#get_service_network_service_association(params = {}) ⇒ Types::GetServiceNetworkServiceAssociationResponse
Retrieves information about the specified association between a service network and a service.
-
#get_service_network_vpc_association(params = {}) ⇒ Types::GetServiceNetworkVpcAssociationResponse
Retrieves information about the specified association between a service network and a VPC.
-
#get_target_group(params = {}) ⇒ Types::GetTargetGroupResponse
Retrieves information about the specified target group.
-
#list_access_log_subscriptions(params = {}) ⇒ Types::ListAccessLogSubscriptionsResponse
Lists the access log subscriptions for the specified service network or service.
-
#list_domain_verifications(params = {}) ⇒ Types::ListDomainVerificationsResponse
Lists the domain verifications.
-
#list_listeners(params = {}) ⇒ Types::ListListenersResponse
Lists the listeners for the specified service.
-
#list_resource_configurations(params = {}) ⇒ Types::ListResourceConfigurationsResponse
Lists the resource configurations owned by or shared with this account.
-
#list_resource_endpoint_associations(params = {}) ⇒ Types::ListResourceEndpointAssociationsResponse
Lists the associations for the specified VPC endpoint.
-
#list_resource_gateways(params = {}) ⇒ Types::ListResourceGatewaysResponse
Lists the resource gateways that you own or that were shared with you.
-
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists the rules for the specified listener.
-
#list_service_network_resource_associations(params = {}) ⇒ Types::ListServiceNetworkResourceAssociationsResponse
Lists the associations between a service network and a resource configuration.
-
#list_service_network_service_associations(params = {}) ⇒ Types::ListServiceNetworkServiceAssociationsResponse
Lists the associations between a service network and a service.
-
#list_service_network_vpc_associations(params = {}) ⇒ Types::ListServiceNetworkVpcAssociationsResponse
Lists the associations between a service network and a VPC.
-
#list_service_network_vpc_endpoint_associations(params = {}) ⇒ Types::ListServiceNetworkVpcEndpointAssociationsResponse
Lists the associations between a service network and a VPC endpoint.
-
#list_service_networks(params = {}) ⇒ Types::ListServiceNetworksResponse
Lists the service networks owned by or shared with this account.
-
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists the services owned by the caller account or shared with the caller account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#list_target_groups(params = {}) ⇒ Types::ListTargetGroupsResponse
Lists your target groups.
-
#list_targets(params = {}) ⇒ Types::ListTargetsResponse
Lists the targets for the target group.
-
#put_auth_policy(params = {}) ⇒ Types::PutAuthPolicyResponse
Creates or updates the auth policy.
-
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based permission policy to a service or service network.
-
#register_targets(params = {}) ⇒ Types::RegisterTargetsResponse
Registers the targets with the target group.
-
#start_domain_verification(params = {}) ⇒ Types::StartDomainVerificationResponse
Starts the domain verification process for a custom domain name.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
-
#update_access_log_subscription(params = {}) ⇒ Types::UpdateAccessLogSubscriptionResponse
Updates the specified access log subscription.
-
#update_listener(params = {}) ⇒ Types::UpdateListenerResponse
Updates the specified listener for the specified service.
-
#update_resource_configuration(params = {}) ⇒ Types::UpdateResourceConfigurationResponse
Updates the specified resource configuration.
-
#update_resource_gateway(params = {}) ⇒ Types::UpdateResourceGatewayResponse
Updates the specified resource gateway.
-
#update_rule(params = {}) ⇒ Types::UpdateRuleResponse
Updates a specified rule for the listener.
-
#update_service(params = {}) ⇒ Types::UpdateServiceResponse
Updates the specified service.
-
#update_service_network(params = {}) ⇒ Types::UpdateServiceNetworkResponse
Updates the specified service network.
-
#update_service_network_vpc_association(params = {}) ⇒ Types::UpdateServiceNetworkVpcAssociationResponse
Updates the service network and VPC association.
-
#update_target_group(params = {}) ⇒ Types::UpdateTargetGroupResponse
Updates the specified target group.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-vpclattice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4679 4680 4681 |
# File 'lib/aws-sdk-vpclattice/client.rb', line 4679 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4682 4683 4684 |
# File 'lib/aws-sdk-vpclattice/client.rb', line 4682 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_update_rule(params = {}) ⇒ Types::BatchUpdateRuleResponse
Updates the listener rules in a batch. You can use this operation to change the priority of listener rules. This can be useful when bulk updating or swapping rule priority.
Required permissions: vpc-lattice:UpdateRule
For more information, see How Amazon VPC Lattice works with IAM in the Amazon VPC Lattice User Guide.
87 |
# File 'sig/client.rbs', line 87
def batch_update_rule: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 |
# File 'lib/aws-sdk-vpclattice/client.rb', line 4652 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::VPCLattice') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-vpclattice' context[:gem_version] = '1.51.0' Seahorse::Client::Request.new(handlers, context) end |
#create_access_log_subscription(params = {}) ⇒ Types::CreateAccessLogSubscriptionResponse
Enables access logs to be sent to Amazon CloudWatch, Amazon S3, and Amazon Kinesis Data Firehose. The service network owner can use the access logs to audit the services in the network. The service network owner can only see access logs from clients and services that are associated with their service network. Access log entries represent traffic originated from VPCs associated with that network. For more information, see Access logs in the Amazon VPC Lattice User Guide.
111 |
# File 'sig/client.rbs', line 111
def create_access_log_subscription: (
|
#create_listener(params = {}) ⇒ Types::CreateListenerResponse
Creates a listener for a service. Before you start using your Amazon VPC Lattice service, you must add one or more listeners. A listener is a process that checks for connection requests to your services. For more information, see Listeners in the Amazon VPC Lattice User Guide.
132 |
# File 'sig/client.rbs', line 132
def create_listener: (
|
#create_resource_configuration(params = {}) ⇒ Types::CreateResourceConfigurationResponse
Creates a resource configuration. A resource configuration defines a specific resource. You can associate a resource configuration with a service network or a VPC endpoint.
164 |
# File 'sig/client.rbs', line 164
def create_resource_configuration: (
|
#create_resource_gateway(params = {}) ⇒ Types::CreateResourceGatewayResponse
A resource gateway is a point of ingress into the VPC where a resource resides. It spans multiple Availability Zones. For your resource to be accessible from all Availability Zones, you should create your resource gateways to span as many Availability Zones as possible. A VPC can have multiple resource gateways.
195 |
# File 'sig/client.rbs', line 195
def create_resource_gateway: (
|
#create_rule(params = {}) ⇒ Types::CreateRuleResponse
Creates a listener rule. Each listener has a default rule for checking connection requests, but you can define additional rules. Each rule consists of a priority, one or more actions, and one or more conditions. For more information, see Listener rules in the Amazon VPC Lattice User Guide.
218 |
# File 'sig/client.rbs', line 218
def create_rule: (
|
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates a service. A service is any software application that can run on instances containers, or serverless functions within an account or virtual private cloud (VPC).
For more information, see Services in the Amazon VPC Lattice User Guide.
243 |
# File 'sig/client.rbs', line 243
def create_service: (
|
#create_service_network(params = {}) ⇒ Types::CreateServiceNetworkResponse
Creates a service network. A service network is a logical boundary for a collection of services. You can associate services and VPCs with a service network.
For more information, see Service networks in the Amazon VPC Lattice User Guide.
263 |
# File 'sig/client.rbs', line 263
def create_service_network: (
|
#create_service_network_resource_association(params = {}) ⇒ Types::CreateServiceNetworkResourceAssociationResponse
Associates the specified service network with the specified resource configuration. This allows the resource configuration to receive connections through the service network, including through a service network VPC endpoint.
283 |
# File 'sig/client.rbs', line 283
def create_service_network_resource_association: (
|
#create_service_network_service_association(params = {}) ⇒ Types::CreateServiceNetworkServiceAssociationResponse
Associates the specified service with the specified service network. For more information, see Manage service associations in the Amazon VPC Lattice User Guide.
You can't use this operation if the service and service network are already associated or if there is a disassociation or deletion in progress. If the association fails, you can retry the operation by deleting the association and recreating it.
You cannot associate a service and service network that are shared with a caller. The caller must own either the service or the service network.
As a result of this operation, the association is created in the service network account and the association owner account.
302 |
# File 'sig/client.rbs', line 302
def create_service_network_service_association: (
|
#create_service_network_vpc_association(params = {}) ⇒ Types::CreateServiceNetworkVpcAssociationResponse
Associates a VPC with a service network. When you associate a VPC with the service network, it enables all the resources within that VPC to be clients and communicate with other services in the service network. For more information, see Manage VPC associations in the Amazon VPC Lattice User Guide.
You can't use this operation if there is a disassociation in progress. If the association fails, retry by deleting the association and recreating it.
As a result of this operation, the association gets created in the service network account and the VPC owner account.
If you add a security group to the service network and VPC association, the association must continue to always have at least one security group. You can add or edit security groups at any time. However, to remove all security groups, you must first delete the association and recreate it without security groups.
321 |
# File 'sig/client.rbs', line 321
def create_service_network_vpc_association: (
|
#create_target_group(params = {}) ⇒ Types::CreateTargetGroupResponse
Creates a target group. A target group is a collection of targets, or compute resources, that run your application or service. A target group can only be used by a single service.
For more information, see Target groups in the Amazon VPC Lattice User Guide.
345 |
# File 'sig/client.rbs', line 345
def create_target_group: (
|
#delete_access_log_subscription(params = {}) ⇒ Struct
Deletes the specified access log subscription.
366 |
# File 'sig/client.rbs', line 366
def delete_access_log_subscription: (
|
#delete_auth_policy(params = {}) ⇒ Struct
Deletes the specified auth policy. If an auth is set to AWS_IAM and
the auth policy is deleted, all requests are denied. If you are trying
to remove the auth policy completely, you must set the auth type to
NONE. If auth is enabled on the resource, but no auth policy is set,
all requests are denied.
375 |
# File 'sig/client.rbs', line 375
def delete_auth_policy: (
|
#delete_domain_verification(params = {}) ⇒ Struct
Deletes the specified domain verification.
384 |
# File 'sig/client.rbs', line 384
def delete_domain_verification: (
|
#delete_listener(params = {}) ⇒ Struct
Deletes the specified listener.
393 |
# File 'sig/client.rbs', line 393
def delete_listener: (
|
#delete_resource_configuration(params = {}) ⇒ Struct
Deletes the specified resource configuration.
403 |
# File 'sig/client.rbs', line 403
def delete_resource_configuration: (
|
#delete_resource_endpoint_association(params = {}) ⇒ Types::DeleteResourceEndpointAssociationResponse
Disassociates the resource configuration from the resource VPC endpoint.
417 |
# File 'sig/client.rbs', line 417
def delete_resource_endpoint_association: (
|
#delete_resource_gateway(params = {}) ⇒ Types::DeleteResourceGatewayResponse
Deletes the specified resource gateway.
430 |
# File 'sig/client.rbs', line 430
def delete_resource_gateway: (
|
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the specified resource policy.
439 |
# File 'sig/client.rbs', line 439
def delete_resource_policy: (
|
#delete_rule(params = {}) ⇒ Struct
Deletes a listener rule. Each listener has a default rule for checking connection requests, but you can define additional rules. Each rule consists of a priority, one or more actions, and one or more conditions. You can delete additional listener rules, but you cannot delete the default rule.
For more information, see Listener rules in the Amazon VPC Lattice User Guide.
448 |
# File 'sig/client.rbs', line 448
def delete_rule: (
|
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Deletes a service. A service can't be deleted if it's associated with a service network. If you delete a service, all resources related to the service, such as the resource policy, auth policy, listeners, listener rules, and access log subscriptions, are also deleted. For more information, see Delete a service in the Amazon VPC Lattice User Guide.
463 |
# File 'sig/client.rbs', line 463
def delete_service: (
|
#delete_service_network(params = {}) ⇒ Struct
Deletes a service network. You can only delete the service network if there is no service or VPC associated with it. If you delete a service network, all resources related to the service network, such as the resource policy, auth policy, and access log subscriptions, are also deleted. For more information, see Delete a service network in the Amazon VPC Lattice User Guide.
472 |
# File 'sig/client.rbs', line 472
def delete_service_network: (
|
#delete_service_network_resource_association(params = {}) ⇒ Types::DeleteServiceNetworkResourceAssociationResponse
Deletes the association between a service network and a resource configuration.
484 |
# File 'sig/client.rbs', line 484
def delete_service_network_resource_association: (
|
#delete_service_network_service_association(params = {}) ⇒ Types::DeleteServiceNetworkServiceAssociationResponse
Deletes the association between a service and a service network. This operation fails if an association is still in progress.
496 |
# File 'sig/client.rbs', line 496
def delete_service_network_service_association: (
|
#delete_service_network_vpc_association(params = {}) ⇒ Types::DeleteServiceNetworkVpcAssociationResponse
Disassociates the VPC from the service network. You can't disassociate the VPC if there is a create or update association in progress.
508 |
# File 'sig/client.rbs', line 508
def delete_service_network_vpc_association: (
|
#delete_target_group(params = {}) ⇒ Types::DeleteTargetGroupResponse
Deletes a target group. You can't delete a target group if it is used in a listener rule or if the target group creation is in progress.
520 |
# File 'sig/client.rbs', line 520
def delete_target_group: (
|
#deregister_targets(params = {}) ⇒ Types::DeregisterTargetsResponse
Deregisters the specified targets from the specified target group.
531 |
# File 'sig/client.rbs', line 531
def deregister_targets: (
|
#get_access_log_subscription(params = {}) ⇒ Types::GetAccessLogSubscriptionResponse
Retrieves information about the specified access log subscription.
554 |
# File 'sig/client.rbs', line 554
def get_access_log_subscription: (
|
#get_auth_policy(params = {}) ⇒ Types::GetAuthPolicyResponse
Retrieves information about the auth policy for the specified service or service network.
567 |
# File 'sig/client.rbs', line 567
def get_auth_policy: (
|
#get_domain_verification(params = {}) ⇒ Types::GetDomainVerificationResponse
Retrieves information about a domain verification.ß
584 |
# File 'sig/client.rbs', line 584
def get_domain_verification: (
|
#get_listener(params = {}) ⇒ Types::GetListenerResponse
Retrieves information about the specified listener for the specified service.
603 |
# File 'sig/client.rbs', line 603
def get_listener: (
|
#get_resource_configuration(params = {}) ⇒ Types::GetResourceConfigurationResponse
Retrieves information about the specified resource configuration.
633 |
# File 'sig/client.rbs', line 633
def get_resource_configuration: (
|
#get_resource_gateway(params = {}) ⇒ Types::GetResourceGatewayResponse
Retrieves information about the specified resource gateway.
656 |
# File 'sig/client.rbs', line 656
def get_resource_gateway: (
|
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Retrieves information about the specified resource policy. The resource policy is an IAM policy created on behalf of the resource owner when they share a resource.
666 |
# File 'sig/client.rbs', line 666
def get_resource_policy: (
|
#get_rule(params = {}) ⇒ Types::GetRuleResponse
Retrieves information about the specified listener rules. You can also retrieve information about the default listener rule. For more information, see Listener rules in the Amazon VPC Lattice User Guide.
684 |
# File 'sig/client.rbs', line 684
def get_rule: (
|
#get_service(params = {}) ⇒ Types::GetServiceResponse
Retrieves information about the specified service.
708 |
# File 'sig/client.rbs', line 708
def get_service: (
|
#get_service_network(params = {}) ⇒ Types::GetServiceNetworkResponse
Retrieves information about the specified service network.
726 |
# File 'sig/client.rbs', line 726
def get_service_network: (
|
#get_service_network_resource_association(params = {}) ⇒ Types::GetServiceNetworkResourceAssociationResponse
Retrieves information about the specified association between a service network and a resource configuration.
754 |
# File 'sig/client.rbs', line 754
def get_service_network_resource_association: (
|
#get_service_network_service_association(params = {}) ⇒ Types::GetServiceNetworkServiceAssociationResponse
Retrieves information about the specified association between a service network and a service.
778 |
# File 'sig/client.rbs', line 778
def get_service_network_service_association: (
|
#get_service_network_vpc_association(params = {}) ⇒ Types::GetServiceNetworkVpcAssociationResponse
Retrieves information about the specified association between a service network and a VPC.
802 |
# File 'sig/client.rbs', line 802
def get_service_network_vpc_association: (
|
#get_target_group(params = {}) ⇒ Types::GetTargetGroupResponse
Retrieves information about the specified target group.
822 |
# File 'sig/client.rbs', line 822
def get_target_group: (
|
#list_access_log_subscriptions(params = {}) ⇒ Types::ListAccessLogSubscriptionsResponse
Lists the access log subscriptions for the specified service network or service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
833 |
# File 'sig/client.rbs', line 833
def list_access_log_subscriptions: (
|
#list_domain_verifications(params = {}) ⇒ Types::ListDomainVerificationsResponse
Lists the domain verifications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
846 |
# File 'sig/client.rbs', line 846
def list_domain_verifications: (
|
#list_listeners(params = {}) ⇒ Types::ListListenersResponse
Lists the listeners for the specified service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
858 |
# File 'sig/client.rbs', line 858
def list_listeners: (
|
#list_resource_configurations(params = {}) ⇒ Types::ListResourceConfigurationsResponse
Lists the resource configurations owned by or shared with this account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
871 |
# File 'sig/client.rbs', line 871
def list_resource_configurations: (
|
#list_resource_endpoint_associations(params = {}) ⇒ Types::ListResourceEndpointAssociationsResponse
Lists the associations for the specified VPC endpoint.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
886 |
# File 'sig/client.rbs', line 886
def list_resource_endpoint_associations: (
|
#list_resource_gateways(params = {}) ⇒ Types::ListResourceGatewaysResponse
Lists the resource gateways that you own or that were shared with you.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
902 |
# File 'sig/client.rbs', line 902
def list_resource_gateways: (
|
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists the rules for the specified listener.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
914 |
# File 'sig/client.rbs', line 914
def list_rules: (
|
#list_service_network_resource_associations(params = {}) ⇒ Types::ListServiceNetworkResourceAssociationsResponse
Lists the associations between a service network and a resource configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
928 |
# File 'sig/client.rbs', line 928
def list_service_network_resource_associations: (
|
#list_service_network_service_associations(params = {}) ⇒ Types::ListServiceNetworkServiceAssociationsResponse
Lists the associations between a service network and a service. You can filter the list either by service or service network. You must provide either the service network identifier or the service identifier.
Every association in Amazon VPC Lattice has a unique Amazon Resource Name (ARN), such as when a service network is associated with a VPC or when a service is associated with a service network. If the association is for a resource is shared with another account, the association includes the local account ID as the prefix in the ARN.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
943 |
# File 'sig/client.rbs', line 943
def list_service_network_service_associations: (
|
#list_service_network_vpc_associations(params = {}) ⇒ Types::ListServiceNetworkVpcAssociationsResponse
Lists the associations between a service network and a VPC. You can filter the list either by VPC or service network. You must provide either the ID of the service network identifier or the ID of the VPC.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
957 |
# File 'sig/client.rbs', line 957
def list_service_network_vpc_associations: (
|
#list_service_network_vpc_endpoint_associations(params = {}) ⇒ Types::ListServiceNetworkVpcEndpointAssociationsResponse
Lists the associations between a service network and a VPC endpoint.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
971 |
# File 'sig/client.rbs', line 971
def list_service_network_vpc_endpoint_associations: (
|
#list_service_networks(params = {}) ⇒ Types::ListServiceNetworksResponse
Lists the service networks owned by or shared with this account. The account ID in the ARN shows which account owns the service network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
984 |
# File 'sig/client.rbs', line 984
def list_service_networks: (
|
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists the services owned by the caller account or shared with the caller account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
996 |
# File 'sig/client.rbs', line 996
def list_services: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
1007 |
# File 'sig/client.rbs', line 1007
def list_tags_for_resource: (
|
#list_target_groups(params = {}) ⇒ Types::ListTargetGroupsResponse
Lists your target groups. You can narrow your search by using the filters below in your request.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1018 |
# File 'sig/client.rbs', line 1018
def list_target_groups: (
|
#list_targets(params = {}) ⇒ Types::ListTargetsResponse
Lists the targets for the target group. By default, all targets are included. You can use this API to check the health status of targets. You can also filter the results by target.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1032 |
# File 'sig/client.rbs', line 1032
def list_targets: (
|
#put_auth_policy(params = {}) ⇒ Types::PutAuthPolicyResponse
Creates or updates the auth policy. The policy string in JSON must not contain newlines or blank lines.
For more information, see Auth policies in the Amazon VPC Lattice User Guide.
1051 |
# File 'sig/client.rbs', line 1051
def put_auth_policy: (
|
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based permission policy to a service or service network. The policy must contain the same actions and condition statements as the Amazon Web Services Resource Access Manager permission for sharing services and service networks.
1061 |
# File 'sig/client.rbs', line 1061
def put_resource_policy: (
|
#register_targets(params = {}) ⇒ Types::RegisterTargetsResponse
Registers the targets with the target group. If it's a Lambda target, you can only have one target in a target group.
1073 |
# File 'sig/client.rbs', line 1073
def register_targets: (
|
#start_domain_verification(params = {}) ⇒ Types::StartDomainVerificationResponse
Starts the domain verification process for a custom domain name.
1093 |
# File 'sig/client.rbs', line 1093
def start_domain_verification: (
|
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
1104 |
# File 'sig/client.rbs', line 1104
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
1114 |
# File 'sig/client.rbs', line 1114
def untag_resource: (
|
#update_access_log_subscription(params = {}) ⇒ Types::UpdateAccessLogSubscriptionResponse
Updates the specified access log subscription.
1129 |
# File 'sig/client.rbs', line 1129
def update_access_log_subscription: (
|
#update_listener(params = {}) ⇒ Types::UpdateListenerResponse
Updates the specified listener for the specified service.
1147 |
# File 'sig/client.rbs', line 1147
def update_listener: (
|
#update_resource_configuration(params = {}) ⇒ Types::UpdateResourceConfigurationResponse
Updates the specified resource configuration.
1169 |
# File 'sig/client.rbs', line 1169
def update_resource_configuration: (
|
#update_resource_gateway(params = {}) ⇒ Types::UpdateResourceGatewayResponse
Updates the specified resource gateway.
1189 |
# File 'sig/client.rbs', line 1189
def update_resource_gateway: (
|
#update_rule(params = {}) ⇒ Types::UpdateRuleResponse
Updates a specified rule for the listener. You can't modify a default
listener rule. To modify a default listener rule, use
UpdateListener.
1206 |
# File 'sig/client.rbs', line 1206
def update_rule: (
|
#update_service(params = {}) ⇒ Types::UpdateServiceResponse
Updates the specified service.
1227 |
# File 'sig/client.rbs', line 1227
def update_service: (
|
#update_service_network(params = {}) ⇒ Types::UpdateServiceNetworkResponse
Updates the specified service network.
1243 |
# File 'sig/client.rbs', line 1243
def update_service_network: (
|
#update_service_network_vpc_association(params = {}) ⇒ Types::UpdateServiceNetworkVpcAssociationResponse
Updates the service network and VPC association. If you add a security group to the service network and VPC association, the association must continue to have at least one security group. You can add or edit security groups at any time. However, to remove all security groups, you must first delete the association and then recreate it without security groups.
1258 |
# File 'sig/client.rbs', line 1258
def update_service_network_vpc_association: (
|
#update_target_group(params = {}) ⇒ Types::UpdateTargetGroupResponse
Updates the specified target group.
1274 |
# File 'sig/client.rbs', line 1274
def update_target_group: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4672 4673 4674 |
# File 'lib/aws-sdk-vpclattice/client.rb', line 4672 def waiter_names [] end |