Module: Aws::VPCLattice::Types

Defined in:
lib/aws-sdk-vpclattice/types.rb

Defined Under Namespace

Classes: AccessDeniedException, AccessLogSubscriptionSummary, ArnResource, BatchUpdateRuleRequest, BatchUpdateRuleResponse, ConflictException, CreateAccessLogSubscriptionRequest, CreateAccessLogSubscriptionResponse, CreateListenerRequest, CreateListenerResponse, CreateResourceConfigurationRequest, CreateResourceConfigurationResponse, CreateResourceGatewayRequest, CreateResourceGatewayResponse, CreateRuleRequest, CreateRuleResponse, CreateServiceNetworkRequest, CreateServiceNetworkResourceAssociationRequest, CreateServiceNetworkResourceAssociationResponse, CreateServiceNetworkResponse, CreateServiceNetworkServiceAssociationRequest, CreateServiceNetworkServiceAssociationResponse, CreateServiceNetworkVpcAssociationRequest, CreateServiceNetworkVpcAssociationResponse, CreateServiceRequest, CreateServiceResponse, CreateTargetGroupRequest, CreateTargetGroupResponse, DeleteAccessLogSubscriptionRequest, DeleteAccessLogSubscriptionResponse, DeleteAuthPolicyRequest, DeleteAuthPolicyResponse, DeleteDomainVerificationRequest, DeleteDomainVerificationResponse, DeleteListenerRequest, DeleteListenerResponse, DeleteResourceConfigurationRequest, DeleteResourceConfigurationResponse, DeleteResourceEndpointAssociationRequest, DeleteResourceEndpointAssociationResponse, DeleteResourceGatewayRequest, DeleteResourceGatewayResponse, DeleteResourcePolicyRequest, DeleteResourcePolicyResponse, DeleteRuleRequest, DeleteRuleResponse, DeleteServiceNetworkRequest, DeleteServiceNetworkResourceAssociationRequest, DeleteServiceNetworkResourceAssociationResponse, DeleteServiceNetworkResponse, DeleteServiceNetworkServiceAssociationRequest, DeleteServiceNetworkServiceAssociationResponse, DeleteServiceNetworkVpcAssociationRequest, DeleteServiceNetworkVpcAssociationResponse, DeleteServiceRequest, DeleteServiceResponse, DeleteTargetGroupRequest, DeleteTargetGroupResponse, DeregisterTargetsRequest, DeregisterTargetsResponse, DnsEntry, DnsOptions, DnsResource, DomainVerificationSummary, FixedResponseAction, ForwardAction, GetAccessLogSubscriptionRequest, GetAccessLogSubscriptionResponse, GetAuthPolicyRequest, GetAuthPolicyResponse, GetDomainVerificationRequest, GetDomainVerificationResponse, GetListenerRequest, GetListenerResponse, GetResourceConfigurationRequest, GetResourceConfigurationResponse, GetResourceGatewayRequest, GetResourceGatewayResponse, GetResourcePolicyRequest, GetResourcePolicyResponse, GetRuleRequest, GetRuleResponse, GetServiceNetworkRequest, GetServiceNetworkResourceAssociationRequest, GetServiceNetworkResourceAssociationResponse, GetServiceNetworkResponse, GetServiceNetworkServiceAssociationRequest, GetServiceNetworkServiceAssociationResponse, GetServiceNetworkVpcAssociationRequest, GetServiceNetworkVpcAssociationResponse, GetServiceRequest, GetServiceResponse, GetTargetGroupRequest, GetTargetGroupResponse, HeaderMatch, HeaderMatchType, HealthCheckConfig, HttpMatch, InternalServerException, IpResource, ListAccessLogSubscriptionsRequest, ListAccessLogSubscriptionsResponse, ListDomainVerificationsRequest, ListDomainVerificationsResponse, ListListenersRequest, ListListenersResponse, ListResourceConfigurationsRequest, ListResourceConfigurationsResponse, ListResourceEndpointAssociationsRequest, ListResourceEndpointAssociationsResponse, ListResourceGatewaysRequest, ListResourceGatewaysResponse, ListRulesRequest, ListRulesResponse, ListServiceNetworkResourceAssociationsRequest, ListServiceNetworkResourceAssociationsResponse, ListServiceNetworkServiceAssociationsRequest, ListServiceNetworkServiceAssociationsResponse, ListServiceNetworkVpcAssociationsRequest, ListServiceNetworkVpcAssociationsResponse, ListServiceNetworkVpcEndpointAssociationsRequest, ListServiceNetworkVpcEndpointAssociationsResponse, ListServiceNetworksRequest, ListServiceNetworksResponse, ListServicesRequest, ListServicesResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListTargetGroupsRequest, ListTargetGroupsResponse, ListTargetsRequest, ListTargetsResponse, ListenerSummary, Matcher, PathMatch, PathMatchType, PutAuthPolicyRequest, PutAuthPolicyResponse, PutResourcePolicyRequest, PutResourcePolicyResponse, RegisterTargetsRequest, RegisterTargetsResponse, ResourceConfigurationDefinition, ResourceConfigurationSummary, ResourceEndpointAssociationSummary, ResourceGatewaySummary, ResourceNotFoundException, RuleAction, RuleMatch, RuleSummary, RuleUpdate, RuleUpdateFailure, RuleUpdateSuccess, ServiceNetworkEndpointAssociation, ServiceNetworkResourceAssociationSummary, ServiceNetworkServiceAssociationSummary, ServiceNetworkSummary, ServiceNetworkVpcAssociationSummary, ServiceQuotaExceededException, ServiceSummary, SharingConfig, StartDomainVerificationRequest, StartDomainVerificationResponse, TagResourceRequest, TagResourceResponse, Target, TargetFailure, TargetGroupConfig, TargetGroupSummary, TargetSummary, ThrottlingException, TxtMethodConfig, UntagResourceRequest, UntagResourceResponse, UpdateAccessLogSubscriptionRequest, UpdateAccessLogSubscriptionResponse, UpdateListenerRequest, UpdateListenerResponse, UpdateResourceConfigurationRequest, UpdateResourceConfigurationResponse, UpdateResourceGatewayRequest, UpdateResourceGatewayResponse, UpdateRuleRequest, UpdateRuleResponse, UpdateServiceNetworkRequest, UpdateServiceNetworkResponse, UpdateServiceNetworkVpcAssociationRequest, UpdateServiceNetworkVpcAssociationResponse, UpdateServiceRequest, UpdateServiceResponse, UpdateTargetGroupRequest, UpdateTargetGroupResponse, ValidationException, ValidationExceptionField, WeightedTargetGroup

Instance Attribute Summary collapse

Instance Attribute Details

#arn_resourceTypes::ArnResource

The Amazon Resource Name (ARN) of the resource.

Returns:



4171
4172
4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
# File 'lib/aws-sdk-vpclattice/types.rb', line 4171

class ResourceConfigurationDefinition < Struct.new(
  :dns_resource,
  :ip_resource,
  :arn_resource,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DnsResource < ResourceConfigurationDefinition; end
  class IpResource < ResourceConfigurationDefinition; end
  class ArnResource < ResourceConfigurationDefinition; end
  class Unknown < ResourceConfigurationDefinition; end
end

#containsString

A contains type match.

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
# File 'lib/aws-sdk-vpclattice/types.rb', line 3110

class HeaderMatchType < Struct.new(
  :exact,
  :prefix,
  :contains,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Exact < HeaderMatchType; end
  class Prefix < HeaderMatchType; end
  class Contains < HeaderMatchType; end
  class Unknown < HeaderMatchType; end
end

#dns_resourceTypes::DnsResource

The DNS name of the resource.

Returns:



4171
4172
4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
# File 'lib/aws-sdk-vpclattice/types.rb', line 4171

class ResourceConfigurationDefinition < Struct.new(
  :dns_resource,
  :ip_resource,
  :arn_resource,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DnsResource < ResourceConfigurationDefinition; end
  class IpResource < ResourceConfigurationDefinition; end
  class ArnResource < ResourceConfigurationDefinition; end
  class Unknown < ResourceConfigurationDefinition; end
end

#exactString

An exact match of the path.

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
# File 'lib/aws-sdk-vpclattice/types.rb', line 3110

class HeaderMatchType < Struct.new(
  :exact,
  :prefix,
  :contains,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Exact < HeaderMatchType; end
  class Prefix < HeaderMatchType; end
  class Contains < HeaderMatchType; end
  class Unknown < HeaderMatchType; end
end

#fixed_responseTypes::FixedResponseAction

The fixed response action. The rule returns a custom HTTP response.



4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
4453
4454
# File 'lib/aws-sdk-vpclattice/types.rb', line 4443

class RuleAction < Struct.new(
  :forward,
  :fixed_response,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Forward < RuleAction; end
  class FixedResponse < RuleAction; end
  class Unknown < RuleAction; end
end

#forwardTypes::ForwardAction

The forward action. Traffic that matches the rule is forwarded to the specified target groups.



4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
4453
4454
# File 'lib/aws-sdk-vpclattice/types.rb', line 4443

class RuleAction < Struct.new(
  :forward,
  :fixed_response,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Forward < RuleAction; end
  class FixedResponse < RuleAction; end
  class Unknown < RuleAction; end
end

#http_codeString

The HTTP code to use when checking for a successful response from a target.

Returns:

  • (String)


3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
# File 'lib/aws-sdk-vpclattice/types.rb', line 3986

class Matcher < Struct.new(
  :http_code,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class HttpCode < Matcher; end
  class Unknown < Matcher; end
end

#http_matchTypes::HttpMatch

The HTTP criteria that a rule must match.

Returns:



4468
4469
4470
4471
4472
4473
4474
4475
4476
4477
# File 'lib/aws-sdk-vpclattice/types.rb', line 4468

class RuleMatch < Struct.new(
  :http_match,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class HttpMatch < RuleMatch; end
  class Unknown < RuleMatch; end
end

#ip_resourceTypes::IpResource

The IP resource.

Returns:



4171
4172
4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
# File 'lib/aws-sdk-vpclattice/types.rb', line 4171

class ResourceConfigurationDefinition < Struct.new(
  :dns_resource,
  :ip_resource,
  :arn_resource,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DnsResource < ResourceConfigurationDefinition; end
  class IpResource < ResourceConfigurationDefinition; end
  class ArnResource < ResourceConfigurationDefinition; end
  class Unknown < ResourceConfigurationDefinition; end
end

#prefixString

A prefix match of the path.

Returns:

  • (String)


3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
# File 'lib/aws-sdk-vpclattice/types.rb', line 3110

class HeaderMatchType < Struct.new(
  :exact,
  :prefix,
  :contains,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Exact < HeaderMatchType; end
  class Prefix < HeaderMatchType; end
  class Contains < HeaderMatchType; end
  class Unknown < HeaderMatchType; end
end