Class: Aws::VPCLattice::Types::ConflictException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

The request conflicts with the current state of the resource. Updating or deleting a resource can cause an inconsistent state.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message ⇒ String

Returns:

  • (String)


161
162
163
164
165
166
167
# File 'lib/aws-sdk-vpclattice/types.rb', line 161

class ConflictException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id ⇒ String

The resource ID.

Returns:

  • (String)


161
162
163
164
165
166
167
# File 'lib/aws-sdk-vpclattice/types.rb', line 161

class ConflictException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type ⇒ String

The resource type.

Returns:

  • (String)


161
162
163
164
165
166
167
# File 'lib/aws-sdk-vpclattice/types.rb', line 161

class ConflictException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end