Class: Aws::VPCLattice::Types::CreateResourceGatewayResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the resource gateway.

Returns:

  • (String)


708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/aws-sdk-vpclattice/types.rb', line 708

class CreateResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_identifier,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the resource gateway.

Returns:

  • (String)


708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/aws-sdk-vpclattice/types.rb', line 708

class CreateResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_identifier,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

The type of IP address for the resource gateway.

Returns:

  • (String)


708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/aws-sdk-vpclattice/types.rb', line 708

class CreateResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_identifier,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#ipv4_addresses_per_eniInteger

The number of IPv4 addresses in each ENI for the resource gateway.

Returns:

  • (Integer)


708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/aws-sdk-vpclattice/types.rb', line 708

class CreateResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_identifier,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the resource gateway.

Returns:

  • (String)


708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/aws-sdk-vpclattice/types.rb', line 708

class CreateResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_identifier,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#resource_config_dns_resolutionString

The DNS resolution type for resource configurations that are associated with this resource gateway.

Returns:

  • (String)


708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/aws-sdk-vpclattice/types.rb', line 708

class CreateResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_identifier,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The IDs of the security groups for the resource gateway.

Returns:

  • (Array<String>)


708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/aws-sdk-vpclattice/types.rb', line 708

class CreateResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_identifier,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the resource gateway.

Returns:

  • (String)


708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/aws-sdk-vpclattice/types.rb', line 708

class CreateResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_identifier,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The IDs of the resource gateway subnets.

Returns:

  • (Array<String>)


708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/aws-sdk-vpclattice/types.rb', line 708

class CreateResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_identifier,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_identifierString

The ID of the VPC.

Returns:

  • (String)


708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/aws-sdk-vpclattice/types.rb', line 708

class CreateResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_identifier,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution)
  SENSITIVE = []
  include Aws::Structure
end