Class: Aws::VPCLattice::Types::CreateRuleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::CreateRuleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ Types::RuleAction
The rule action.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the rule.
-
#id ⇒ String
The ID of the rule.
-
#match ⇒ Types::RuleMatch
The rule match.
-
#name ⇒ String
The name of the rule.
-
#priority ⇒ Integer
The priority assigned to the rule.
Instance Attribute Details
#action ⇒ Types::RuleAction
The rule action.
811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 811 class CreateRuleResponse < Struct.new( :arn, :id, :name, :match, :priority, :action) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the rule.
811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 811 class CreateRuleResponse < Struct.new( :arn, :id, :name, :match, :priority, :action) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the rule.
811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 811 class CreateRuleResponse < Struct.new( :arn, :id, :name, :match, :priority, :action) SENSITIVE = [] include Aws::Structure end |
#match ⇒ Types::RuleMatch
The rule match. The ‘RuleMatch` must be an `HttpMatch`. This means that the rule should be an exact match on HTTP constraints which are made up of the HTTP method, path, and header.
811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 811 class CreateRuleResponse < Struct.new( :arn, :id, :name, :match, :priority, :action) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule.
811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 811 class CreateRuleResponse < Struct.new( :arn, :id, :name, :match, :priority, :action) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The priority assigned to the rule. The lower the priority number the higher the priority.
811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 811 class CreateRuleResponse < Struct.new( :arn, :id, :name, :match, :priority, :action) SENSITIVE = [] include Aws::Structure end |