Class: Aws::VPCLattice::Types::CreateServiceNetworkResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::CreateServiceNetworkResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
-
#auth_type ⇒ String
The type of IAM policy.
-
#id ⇒ String
The ID of the service network.
-
#name ⇒ String
The name of the service network.
-
#sharing_config ⇒ Types::SharingConfig
Specifies if the service network is enabled for sharing.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1018 class CreateServiceNetworkResponse < Struct.new( :id, :name, :arn, :sharing_config, :auth_type) SENSITIVE = [] include Aws::Structure end |
#auth_type ⇒ String
The type of IAM policy.
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1018 class CreateServiceNetworkResponse < Struct.new( :id, :name, :arn, :sharing_config, :auth_type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the service network.
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1018 class CreateServiceNetworkResponse < Struct.new( :id, :name, :arn, :sharing_config, :auth_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the service network.
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1018 class CreateServiceNetworkResponse < Struct.new( :id, :name, :arn, :sharing_config, :auth_type) SENSITIVE = [] include Aws::Structure end |
#sharing_config ⇒ Types::SharingConfig
Specifies if the service network is enabled for sharing.
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1018 class CreateServiceNetworkResponse < Struct.new( :id, :name, :arn, :sharing_config, :auth_type) SENSITIVE = [] include Aws::Structure end |