Class: Aws::VPCLattice::Types::CreateServiceNetworkServiceAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token and parameters, the retry succeeds without performing any actions. If the parameters aren't identical, the retry fails.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1054
1055
1056
1057
1058
1059
1060
1061
# File 'lib/aws-sdk-vpclattice/types.rb', line 1054

class CreateServiceNetworkServiceAssociationRequest < Struct.new(
  :client_token,
  :service_identifier,
  :service_network_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#service_identifier ⇒ String

The ID or ARN of the service.

Returns:

  • (String)


1054
1055
1056
1057
1058
1059
1060
1061
# File 'lib/aws-sdk-vpclattice/types.rb', line 1054

class CreateServiceNetworkServiceAssociationRequest < Struct.new(
  :client_token,
  :service_identifier,
  :service_network_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_identifier ⇒ String

The ID or ARN of the service network. You must use an ARN if the resources are in different accounts.

Returns:

  • (String)


1054
1055
1056
1057
1058
1059
1060
1061
# File 'lib/aws-sdk-vpclattice/types.rb', line 1054

class CreateServiceNetworkServiceAssociationRequest < Struct.new(
  :client_token,
  :service_identifier,
  :service_network_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags for the association.

Returns:

  • (Hash<String,String>)


1054
1055
1056
1057
1058
1059
1060
1061
# File 'lib/aws-sdk-vpclattice/types.rb', line 1054

class CreateServiceNetworkServiceAssociationRequest < Struct.new(
  :client_token,
  :service_identifier,
  :service_network_identifier,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end