Class: Aws::VPCLattice::Types::CreateServiceNetworkVpcAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token and parameters, the retry succeeds without performing any actions. If the parameters aren't identical, the retry fails.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-vpclattice/types.rb', line 1147

class CreateServiceNetworkVpcAssociationRequest < Struct.new(
  :client_token,
  :service_network_identifier,
  :vpc_identifier,
  :private_dns_enabled,
  :security_group_ids,
  :tags,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#dns_options ⇒ Types::DnsOptions

DNS options for the service network VPC association.

Returns:



1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-vpclattice/types.rb', line 1147

class CreateServiceNetworkVpcAssociationRequest < Struct.new(
  :client_token,
  :service_network_identifier,
  :vpc_identifier,
  :private_dns_enabled,
  :security_group_ids,
  :tags,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_enabled ⇒ Boolean

Indicates if private DNS is enabled for the VPC association.

Returns:

  • (Boolean)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-vpclattice/types.rb', line 1147

class CreateServiceNetworkVpcAssociationRequest < Struct.new(
  :client_token,
  :service_network_identifier,
  :vpc_identifier,
  :private_dns_enabled,
  :security_group_ids,
  :tags,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_ids ⇒ Array<String>

The IDs of the security groups. Security groups aren't added by default. You can add a security group to apply network level controls to control which resources in a VPC are allowed to access the service network and its services. For more information, see Control traffic to resources using security groups in the Amazon VPC User Guide.

Returns:

  • (Array<String>)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-vpclattice/types.rb', line 1147

class CreateServiceNetworkVpcAssociationRequest < Struct.new(
  :client_token,
  :service_network_identifier,
  :vpc_identifier,
  :private_dns_enabled,
  :security_group_ids,
  :tags,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_identifier ⇒ String

The ID or ARN of the service network. You must use an ARN if the resources are in different accounts.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-vpclattice/types.rb', line 1147

class CreateServiceNetworkVpcAssociationRequest < Struct.new(
  :client_token,
  :service_network_identifier,
  :vpc_identifier,
  :private_dns_enabled,
  :security_group_ids,
  :tags,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags for the association.

Returns:

  • (Hash<String,String>)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-vpclattice/types.rb', line 1147

class CreateServiceNetworkVpcAssociationRequest < Struct.new(
  :client_token,
  :service_network_identifier,
  :vpc_identifier,
  :private_dns_enabled,
  :security_group_ids,
  :tags,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_identifier ⇒ String

The ID of the VPC.

Returns:

  • (String)


1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-vpclattice/types.rb', line 1147

class CreateServiceNetworkVpcAssociationRequest < Struct.new(
  :client_token,
  :service_network_identifier,
  :vpc_identifier,
  :private_dns_enabled,
  :security_group_ids,
  :tags,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end