Class: Aws::VPCLattice::Types::CreateServiceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_typeString

The type of IAM policy.

  • NONE: The resource does not use an IAM policy. This is the default.

  • AWS_IAM: The resource uses an IAM policy. When this type is used, auth is enabled and an auth policy is required.

Returns:

  • (String)


1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
# File 'lib/aws-sdk-vpclattice/types.rb', line 1201

class CreateServiceRequest < Struct.new(
  :client_token,
  :name,
  :tags,
  :custom_domain_name,
  :certificate_arn,
  :auth_type,
  :idle_timeout_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_arnString

The Amazon Resource Name (ARN) of the certificate.

Returns:

  • (String)


1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
# File 'lib/aws-sdk-vpclattice/types.rb', line 1201

class CreateServiceRequest < Struct.new(
  :client_token,
  :name,
  :tags,
  :custom_domain_name,
  :certificate_arn,
  :auth_type,
  :idle_timeout_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token and parameters, the retry succeeds without performing any actions. If the parameters aren't identical, the retry fails.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
# File 'lib/aws-sdk-vpclattice/types.rb', line 1201

class CreateServiceRequest < Struct.new(
  :client_token,
  :name,
  :tags,
  :custom_domain_name,
  :certificate_arn,
  :auth_type,
  :idle_timeout_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#custom_domain_nameString

The custom domain name of the service.

Returns:

  • (String)


1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
# File 'lib/aws-sdk-vpclattice/types.rb', line 1201

class CreateServiceRequest < Struct.new(
  :client_token,
  :name,
  :tags,
  :custom_domain_name,
  :certificate_arn,
  :auth_type,
  :idle_timeout_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#idle_timeout_secondsInteger

The amount of time, in seconds, that a connection can remain idle (no data sent) before VPC Lattice closes it. The valid range is 60 to 600 seconds. If you don't specify a value, the default is 60 seconds. This setting does not change the maximum connection duration of 10 minutes; connections are still closed when they reach that limit.

Returns:

  • (Integer)


1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
# File 'lib/aws-sdk-vpclattice/types.rb', line 1201

class CreateServiceRequest < Struct.new(
  :client_token,
  :name,
  :tags,
  :custom_domain_name,
  :certificate_arn,
  :auth_type,
  :idle_timeout_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the service. The name must be unique within the account. The valid characters are a-z, 0-9, and hyphens (-). You can't use a hyphen as the first or last character, or immediately after another hyphen.

Returns:

  • (String)


1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
# File 'lib/aws-sdk-vpclattice/types.rb', line 1201

class CreateServiceRequest < Struct.new(
  :client_token,
  :name,
  :tags,
  :custom_domain_name,
  :certificate_arn,
  :auth_type,
  :idle_timeout_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags for the service.

Returns:

  • (Hash<String,String>)


1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
# File 'lib/aws-sdk-vpclattice/types.rb', line 1201

class CreateServiceRequest < Struct.new(
  :client_token,
  :name,
  :tags,
  :custom_domain_name,
  :certificate_arn,
  :auth_type,
  :idle_timeout_seconds)
  SENSITIVE = []
  include Aws::Structure
end