Class: Aws::VPCLattice::Types::DeleteServiceNetworkVpcAssociationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


1725
1726
1727
1728
1729
1730
1731
# File 'lib/aws-sdk-vpclattice/types.rb', line 1725

class DeleteServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the association.

Returns:

  • (String)


1725
1726
1727
1728
1729
1730
1731
# File 'lib/aws-sdk-vpclattice/types.rb', line 1725

class DeleteServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status. You can retry the operation if the status is DELETE_FAILED. However, if you retry it while the status is DELETE_IN_PROGRESS, there is no change in the status.

Returns:

  • (String)


1725
1726
1727
1728
1729
1730
1731
# File 'lib/aws-sdk-vpclattice/types.rb', line 1725

class DeleteServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end