Class: Aws::VPCLattice::Types::DeleteServiceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the service.

Returns:

  • (String)


1765
1766
1767
1768
1769
1770
1771
1772
# File 'lib/aws-sdk-vpclattice/types.rb', line 1765

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the service.

Returns:

  • (String)


1765
1766
1767
1768
1769
1770
1771
1772
# File 'lib/aws-sdk-vpclattice/types.rb', line 1765

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the service.

Returns:

  • (String)


1765
1766
1767
1768
1769
1770
1771
1772
# File 'lib/aws-sdk-vpclattice/types.rb', line 1765

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status. You can retry the operation if the status is DELETE_FAILED. However, if you retry it while the status is DELETE_IN_PROGRESS, the status doesn't change.

Returns:

  • (String)


1765
1766
1767
1768
1769
1770
1771
1772
# File 'lib/aws-sdk-vpclattice/types.rb', line 1765

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end