Class: Aws::VPCLattice::Types::DnsOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

The DNS configuration options.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#private_dns_preferenceString

The preference for which private domains have a private hosted zone created for and associated with the specified VPC. Only supported when private DNS is enabled and when the VPC endpoint type is ServiceNetwork or Resource.

  • ALL_DOMAINS - VPC Lattice provisions private hosted zones for all custom domain names.

  • VERIFIED_DOMAINS_ONLY - VPC Lattice provisions a private hosted zone only if custom domain name has been verified by the provider.

  • VERIFIED_DOMAINS_AND_SPECIFIED_DOMAINS - VPC Lattice provisions private hosted zones for all verified custom domain names and other domain names that the resource consumer specifies. The resource consumer specifies the domain names in the privateDnsSpecifiedDomains parameter.

  • SPECIFIED_DOMAINS_ONLY - VPC Lattice provisions a private hosted zone for domain names specified by the resource consumer. The resource consumer specifies the domain names in the privateDnsSpecifiedDomains parameter.

Returns:

  • (String)


1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-vpclattice/types.rb', line 1848

class DnsOptions < Struct.new(
  :private_dns_preference,
  :private_dns_specified_domains)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_specified_domainsArray<String>

Indicates which of the private domains to create private hosted zones for and associate with the specified VPC. Only supported when private DNS is enabled and the private DNS preference is VERIFIED_DOMAINS_AND_SPECIFIED_DOMAINS or SPECIFIED_DOMAINS_ONLY.

Returns:

  • (Array<String>)


1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-vpclattice/types.rb', line 1848

class DnsOptions < Struct.new(
  :private_dns_preference,
  :private_dns_specified_domains)
  SENSITIVE = []
  include Aws::Structure
end