Class: Aws::VPCLattice::Types::GetAccessLogSubscriptionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the access log subscription.

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
# File 'lib/aws-sdk-vpclattice/types.rb', line 1997

class GetAccessLogSubscriptionResponse < Struct.new(
  :id,
  :arn,
  :resource_id,
  :resource_arn,
  :destination_arn,
  :service_network_log_type,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the access log subscription was created, in ISO-8601 format.

Returns:

  • (Time)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
# File 'lib/aws-sdk-vpclattice/types.rb', line 1997

class GetAccessLogSubscriptionResponse < Struct.new(
  :id,
  :arn,
  :resource_id,
  :resource_arn,
  :destination_arn,
  :service_network_log_type,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#destination_arnString

The Amazon Resource Name (ARN) of the access log destination.

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
# File 'lib/aws-sdk-vpclattice/types.rb', line 1997

class GetAccessLogSubscriptionResponse < Struct.new(
  :id,
  :arn,
  :resource_id,
  :resource_arn,
  :destination_arn,
  :service_network_log_type,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the access log subscription.

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
# File 'lib/aws-sdk-vpclattice/types.rb', line 1997

class GetAccessLogSubscriptionResponse < Struct.new(
  :id,
  :arn,
  :resource_id,
  :resource_arn,
  :destination_arn,
  :service_network_log_type,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The date and time that the access log subscription was last updated, in ISO-8601 format.

Returns:

  • (Time)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
# File 'lib/aws-sdk-vpclattice/types.rb', line 1997

class GetAccessLogSubscriptionResponse < Struct.new(
  :id,
  :arn,
  :resource_id,
  :resource_arn,
  :destination_arn,
  :service_network_log_type,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the service network or service.

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
# File 'lib/aws-sdk-vpclattice/types.rb', line 1997

class GetAccessLogSubscriptionResponse < Struct.new(
  :id,
  :arn,
  :resource_id,
  :resource_arn,
  :destination_arn,
  :service_network_log_type,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The ID of the service network or service.

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
# File 'lib/aws-sdk-vpclattice/types.rb', line 1997

class GetAccessLogSubscriptionResponse < Struct.new(
  :id,
  :arn,
  :resource_id,
  :resource_arn,
  :destination_arn,
  :service_network_log_type,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_log_typeString

The log type for the service network.

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
# File 'lib/aws-sdk-vpclattice/types.rb', line 1997

class GetAccessLogSubscriptionResponse < Struct.new(
  :id,
  :arn,
  :resource_id,
  :resource_arn,
  :destination_arn,
  :service_network_log_type,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end