Class: Aws::VPCLattice::Types::GetAuthPolicyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_at ⇒ Time

The date and time that the auth policy was created, in ISO-8601 format.

Returns:

  • (Time)


2119
2120
2121
2122
2123
2124
2125
2126
# File 'lib/aws-sdk-vpclattice/types.rb', line 2119

class GetAuthPolicyResponse < Struct.new(
  :policy,
  :state,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The date and time that the auth policy was last updated, in ISO-8601 format.

Returns:

  • (Time)


2119
2120
2121
2122
2123
2124
2125
2126
# File 'lib/aws-sdk-vpclattice/types.rb', line 2119

class GetAuthPolicyResponse < Struct.new(
  :policy,
  :state,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#policy ⇒ String

The auth policy.

Returns:

  • (String)


2119
2120
2121
2122
2123
2124
2125
2126
# File 'lib/aws-sdk-vpclattice/types.rb', line 2119

class GetAuthPolicyResponse < Struct.new(
  :policy,
  :state,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ String

The state of the auth policy. The auth policy is only active when the auth type is set to AWS_IAM. If you provide a policy, then authentication and authorization decisions are made based on this policy and the client's IAM policy. If the auth type is NONE, then any auth policy that you provide remains inactive. For more information, see Create a service network in the Amazon VPC Lattice User Guide.

Returns:

  • (String)


2119
2120
2121
2122
2123
2124
2125
2126
# File 'lib/aws-sdk-vpclattice/types.rb', line 2119

class GetAuthPolicyResponse < Struct.new(
  :policy,
  :state,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end