Class: Aws::VPCLattice::Types::GetDomainVerificationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the domain verification.

Returns:

  • (String)


2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/aws-sdk-vpclattice/types.rb', line 2176

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the domain verification was created, in ISO-8601 format.

Returns:

  • (Time)


2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/aws-sdk-vpclattice/types.rb', line 2176

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#domain_name ⇒ String

The domain name being verified.

Returns:

  • (String)


2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/aws-sdk-vpclattice/types.rb', line 2176

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the domain verification.

Returns:

  • (String)


2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/aws-sdk-vpclattice/types.rb', line 2176

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_verified_time ⇒ Time

The date and time that the domain was last successfully verified, in ISO-8601 format.

Returns:

  • (Time)


2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/aws-sdk-vpclattice/types.rb', line 2176

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the domain verification process.

Returns:

  • (String)


2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/aws-sdk-vpclattice/types.rb', line 2176

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags associated with the domain verification.

Returns:

  • (Hash<String,String>)


2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/aws-sdk-vpclattice/types.rb', line 2176

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#txt_method_config ⇒ Types::TxtMethodConfig

The TXT record configuration used for domain verification.



2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/aws-sdk-vpclattice/types.rb', line 2176

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end