Class: Aws::VPCLattice::Types::GetResourceGatewayResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the resource gateway.

Returns:

  • (String)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the resource gateway was created, in ISO-8601 format.

Returns:

  • (Time)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the resource gateway.

Returns:

  • (String)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_type ⇒ String

The type of IP address for the resource gateway.

Returns:

  • (String)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#ipv4_addresses_per_eni ⇒ Integer

The number of IPv4 addresses in each ENI for the resource gateway.

Returns:

  • (Integer)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The date and time that the resource gateway was last updated, in ISO-8601 format.

Returns:

  • (Time)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#managed_by ⇒ String

The Amazon Web Services service that manages the resource gateway.

Returns:

  • (String)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the resource gateway.

Returns:

  • (String)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#resource_config_dns_resolution ⇒ String

The DNS resolution type for resource configurations that are associated with this resource gateway.

Returns:

  • (String)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_ids ⇒ Array<String>

The security group IDs associated with the resource gateway.

Returns:

  • (Array<String>)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_managed ⇒ Boolean

Indicates whether the resource gateway is managed by an Amazon Web Services service.

Returns:

  • (Boolean)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status for the resource gateway.

Returns:

  • (String)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_ids ⇒ Array<String>

The IDs of the VPC subnets for resource gateway.

Returns:

  • (Array<String>)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_id ⇒ String

The ID of the VPC for the resource gateway.

Returns:

  • (String)


2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/aws-sdk-vpclattice/types.rb', line 2481

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end