Class: Aws::VPCLattice::Types::GetServiceNetworkResourceAssociationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the association was created, in ISO-8601 format.

Returns:

  • (Time)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

The account that created the association.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#dns_entry ⇒ Types::DnsEntry

The DNS entry for the service.

Returns:



2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#domain_verification_status ⇒ String

The domain verification status in the service network resource association.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#failure_code ⇒ String

The failure code.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

The reason the association request failed.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the association.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#is_managed_association ⇒ Boolean

Indicates whether the association is managed by Amazon.

Returns:

  • (Boolean)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The most recent date and time that the association was updated, in ISO-8601 format.

Returns:

  • (Time)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_enabled ⇒ Boolean

Indicates if private DNS is enabled in the service network resource association.

Returns:

  • (Boolean)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_entry ⇒ Types::DnsEntry

The private DNS entry for the service. This entry includes only the domain name.

Returns:



2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_id ⇒ String

The ID of the resource configuration that is associated with the service network.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_name ⇒ String

The name of the resource configuration that is associated with the service network.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_arn ⇒ String

The Amazon Resource Name (ARN) of the service network that is associated with the resource configuration.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_id ⇒ String

The ID of the service network that is associated with the resource configuration.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_name ⇒ String

The name of the service network that is associated with the resource configuration.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the association.

Returns:

  • (String)


2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
# File 'lib/aws-sdk-vpclattice/types.rb', line 2712

class GetServiceNetworkResourceAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :failure_reason,
  :failure_code,
  :last_updated_at,
  :private_dns_entry,
  :private_dns_enabled,
  :dns_entry,
  :is_managed_association,
  :domain_verification_status)
  SENSITIVE = []
  include Aws::Structure
end