Class: Aws::VPCLattice::Types::GetServiceNetworkResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the service network.

Returns:

  • (String)


2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
# File 'lib/aws-sdk-vpclattice/types.rb', line 2775

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#auth_type ⇒ String

The type of IAM policy.

Returns:

  • (String)


2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
# File 'lib/aws-sdk-vpclattice/types.rb', line 2775

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the service network was created, in ISO-8601 format.

Returns:

  • (Time)


2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
# File 'lib/aws-sdk-vpclattice/types.rb', line 2775

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the service network.

Returns:

  • (String)


2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
# File 'lib/aws-sdk-vpclattice/types.rb', line 2775

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The date and time of the last update, in ISO-8601 format.

Returns:

  • (Time)


2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
# File 'lib/aws-sdk-vpclattice/types.rb', line 2775

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the service network.

Returns:

  • (String)


2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
# File 'lib/aws-sdk-vpclattice/types.rb', line 2775

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_associated_services ⇒ Integer

The number of services associated with the service network.

Returns:

  • (Integer)


2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
# File 'lib/aws-sdk-vpclattice/types.rb', line 2775

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_associated_vp_cs ⇒ Integer

The number of VPCs associated with the service network.

Returns:

  • (Integer)


2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
# File 'lib/aws-sdk-vpclattice/types.rb', line 2775

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#sharing_config ⇒ Types::SharingConfig

Specifies if the service network is enabled for sharing.



2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
# File 'lib/aws-sdk-vpclattice/types.rb', line 2775

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end