Class: Aws::VPCLattice::Types::GetServiceNetworkVpcAssociationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the association was created, in ISO-8601 format.

Returns:

  • (Time)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

The account that created the association.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#dns_options ⇒ Types::DnsOptions

DNS options for the service network VPC association.

Returns:



2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#failure_code ⇒ String

The failure code.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#failure_message ⇒ String

The failure message.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the association.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The date and time that the association was last updated, in ISO-8601 format.

Returns:

  • (Time)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_enabled ⇒ Boolean

Indicates if private DNS is enabled in the VPC association.

Returns:

  • (Boolean)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_ids ⇒ Array<String>

The IDs of the security groups.

Returns:

  • (Array<String>)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_arn ⇒ String

The Amazon Resource Name (ARN) of the service network.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_id ⇒ String

The ID of the service network.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_name ⇒ String

The name of the service network.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the association.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_id ⇒ String

The ID of the VPC.

Returns:

  • (String)


2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
# File 'lib/aws-sdk-vpclattice/types.rb', line 2960

class GetServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :vpc_id,
  :security_group_ids,
  :private_dns_enabled,
  :failure_message,
  :failure_code,
  :last_updated_at,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end