Class: Aws::VPCLattice::Types::GetServiceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the service.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#auth_type ⇒ String

The type of IAM policy.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_arn ⇒ String

The Amazon Resource Name (ARN) of the certificate.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the service was created, in ISO-8601 format.

Returns:

  • (Time)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#custom_domain_name ⇒ String

The custom domain name of the service.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#dns_entry ⇒ Types::DnsEntry

The DNS name of the service.

Returns:



3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#failure_code ⇒ String

The failure code.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#failure_message ⇒ String

The failure message.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the service.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#idle_timeout_seconds ⇒ Integer

The amount of time, in seconds, that a connection can remain idle before VPC Lattice closes it.

Returns:

  • (Integer)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The date and time that the service was last updated, in ISO-8601 format.

Returns:

  • (Time)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the service.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the service.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end