Class: Aws::VPCLattice::Types::GetTargetGroupResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the target group.

Returns:

  • (String)


3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-vpclattice/types.rb', line 3126

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#config ⇒ Types::TargetGroupConfig

The target group configuration.



3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-vpclattice/types.rb', line 3126

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the target group was created, in ISO-8601 format.

Returns:

  • (Time)


3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-vpclattice/types.rb', line 3126

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#failure_code ⇒ String

The failure code.

Returns:

  • (String)


3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-vpclattice/types.rb', line 3126

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#failure_message ⇒ String

The failure message.

Returns:

  • (String)


3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-vpclattice/types.rb', line 3126

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the target group.

Returns:

  • (String)


3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-vpclattice/types.rb', line 3126

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The date and time that the target group was last updated, in ISO-8601 format.

Returns:

  • (Time)


3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-vpclattice/types.rb', line 3126

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the target group.

Returns:

  • (String)


3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-vpclattice/types.rb', line 3126

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#service_arns ⇒ Array<String>

The Amazon Resource Names (ARNs) of the service.

Returns:

  • (Array<String>)


3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-vpclattice/types.rb', line 3126

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status.

Returns:

  • (String)


3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-vpclattice/types.rb', line 3126

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The target group type.

Returns:

  • (String)


3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
# File 'lib/aws-sdk-vpclattice/types.rb', line 3126

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end