Class: Aws::VPCLattice::Types::HeaderMatchType

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Note:

HeaderMatchType is a union - when making an API calls you must set exactly one of the members.

Note:

HeaderMatchType is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of HeaderMatchType corresponding to the set member.

Describes a header match type.

Defined Under Namespace

Classes: Contains, Exact, Prefix, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contains ⇒ String

A contains type match.

Returns:

  • (String)


3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
3201
# File 'lib/aws-sdk-vpclattice/types.rb', line 3188

class HeaderMatchType < Struct.new(
  :exact,
  :prefix,
  :contains,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Exact < HeaderMatchType; end
  class Prefix < HeaderMatchType; end
  class Contains < HeaderMatchType; end
  class Unknown < HeaderMatchType; end
end

#exact ⇒ String

An exact type match.

Returns:

  • (String)


3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
3201
# File 'lib/aws-sdk-vpclattice/types.rb', line 3188

class HeaderMatchType < Struct.new(
  :exact,
  :prefix,
  :contains,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Exact < HeaderMatchType; end
  class Prefix < HeaderMatchType; end
  class Contains < HeaderMatchType; end
  class Unknown < HeaderMatchType; end
end

#prefix ⇒ String

A prefix type match. Matches the value with the prefix.

Returns:

  • (String)


3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
3201
# File 'lib/aws-sdk-vpclattice/types.rb', line 3188

class HeaderMatchType < Struct.new(
  :exact,
  :prefix,
  :contains,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Exact < HeaderMatchType; end
  class Prefix < HeaderMatchType; end
  class Contains < HeaderMatchType; end
  class Unknown < HeaderMatchType; end
end

#unknown ⇒ Object

Returns the value of attribute unknown

Returns:

  • (Object) —

    the current value of unknown



3188
3189
3190
# File 'lib/aws-sdk-vpclattice/types.rb', line 3188

def unknown
  @unknown
end