Class: Aws::VPCLattice::Types::ListResourceConfigurationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_verification_identifier ⇒ String

The domain verification ID.

Returns:

  • (String)


3470
3471
3472
3473
3474
3475
3476
3477
3478
# File 'lib/aws-sdk-vpclattice/types.rb', line 3470

class ListResourceConfigurationsRequest < Struct.new(
  :resource_gateway_identifier,
  :resource_configuration_group_identifier,
  :domain_verification_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum page size.

Returns:

  • (Integer)


3470
3471
3472
3473
3474
3475
3476
3477
3478
# File 'lib/aws-sdk-vpclattice/types.rb', line 3470

class ListResourceConfigurationsRequest < Struct.new(
  :resource_gateway_identifier,
  :resource_configuration_group_identifier,
  :domain_verification_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A pagination token for the next page of results.

Returns:

  • (String)


3470
3471
3472
3473
3474
3475
3476
3477
3478
# File 'lib/aws-sdk-vpclattice/types.rb', line 3470

class ListResourceConfigurationsRequest < Struct.new(
  :resource_gateway_identifier,
  :resource_configuration_group_identifier,
  :domain_verification_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_group_identifier ⇒ String

The ID of the resource configuration of type Group.

Returns:

  • (String)


3470
3471
3472
3473
3474
3475
3476
3477
3478
# File 'lib/aws-sdk-vpclattice/types.rb', line 3470

class ListResourceConfigurationsRequest < Struct.new(
  :resource_gateway_identifier,
  :resource_configuration_group_identifier,
  :domain_verification_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_gateway_identifier ⇒ String

The ID of the resource gateway for the resource configuration.

Returns:

  • (String)


3470
3471
3472
3473
3474
3475
3476
3477
3478
# File 'lib/aws-sdk-vpclattice/types.rb', line 3470

class ListResourceConfigurationsRequest < Struct.new(
  :resource_gateway_identifier,
  :resource_configuration_group_identifier,
  :domain_verification_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end