Class: Aws::VPCLattice::Types::ListResourceEndpointAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

The maximum page size.

Returns:

  • (Integer)


3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
# File 'lib/aws-sdk-vpclattice/types.rb', line 3525

class ListResourceEndpointAssociationsRequest < Struct.new(
  :resource_configuration_identifier,
  :resource_endpoint_association_identifier,
  :vpc_endpoint_id,
  :vpc_endpoint_owner,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A pagination token for the next page of results.

Returns:

  • (String)


3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
# File 'lib/aws-sdk-vpclattice/types.rb', line 3525

class ListResourceEndpointAssociationsRequest < Struct.new(
  :resource_configuration_identifier,
  :resource_endpoint_association_identifier,
  :vpc_endpoint_id,
  :vpc_endpoint_owner,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_identifier ⇒ String

The ID for the resource configuration associated with the VPC endpoint.

Returns:

  • (String)


3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
# File 'lib/aws-sdk-vpclattice/types.rb', line 3525

class ListResourceEndpointAssociationsRequest < Struct.new(
  :resource_configuration_identifier,
  :resource_endpoint_association_identifier,
  :vpc_endpoint_id,
  :vpc_endpoint_owner,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_endpoint_association_identifier ⇒ String

The ID of the association.

Returns:

  • (String)


3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
# File 'lib/aws-sdk-vpclattice/types.rb', line 3525

class ListResourceEndpointAssociationsRequest < Struct.new(
  :resource_configuration_identifier,
  :resource_endpoint_association_identifier,
  :vpc_endpoint_id,
  :vpc_endpoint_owner,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_id ⇒ String

The ID of the VPC endpoint in the association.

Returns:

  • (String)


3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
# File 'lib/aws-sdk-vpclattice/types.rb', line 3525

class ListResourceEndpointAssociationsRequest < Struct.new(
  :resource_configuration_identifier,
  :resource_endpoint_association_identifier,
  :vpc_endpoint_id,
  :vpc_endpoint_owner,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_owner ⇒ String

The owner of the VPC endpoint in the association.

Returns:

  • (String)


3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
# File 'lib/aws-sdk-vpclattice/types.rb', line 3525

class ListResourceEndpointAssociationsRequest < Struct.new(
  :resource_configuration_identifier,
  :resource_endpoint_association_identifier,
  :vpc_endpoint_id,
  :vpc_endpoint_owner,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end