Class: Aws::VPCLattice::Types::ListTargetGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::ListTargetGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
A pagination token for the next page of results.
-
#target_group_type ⇒ String
The target group type.
-
#vpc_identifier ⇒ String
The ID or ARN of the VPC.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return.
3933 3934 3935 3936 3937 3938 3939 3940 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3933 class ListTargetGroupsRequest < Struct.new( :max_results, :next_token, :vpc_identifier, :target_group_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token for the next page of results.
3933 3934 3935 3936 3937 3938 3939 3940 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3933 class ListTargetGroupsRequest < Struct.new( :max_results, :next_token, :vpc_identifier, :target_group_type) SENSITIVE = [] include Aws::Structure end |
#target_group_type ⇒ String
The target group type.
3933 3934 3935 3936 3937 3938 3939 3940 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3933 class ListTargetGroupsRequest < Struct.new( :max_results, :next_token, :vpc_identifier, :target_group_type) SENSITIVE = [] include Aws::Structure end |
#vpc_identifier ⇒ String
The ID or ARN of the VPC.
3933 3934 3935 3936 3937 3938 3939 3940 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3933 class ListTargetGroupsRequest < Struct.new( :max_results, :next_token, :vpc_identifier, :target_group_type) SENSITIVE = [] include Aws::Structure end |