Class: Aws::VPCLattice::Types::PutAuthPolicyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policyString

The auth policy. The policy string in JSON must not contain newlines or blank lines.

Returns:

  • (String)


4110
4111
4112
4113
4114
4115
# File 'lib/aws-sdk-vpclattice/types.rb', line 4110

class PutAuthPolicyResponse < Struct.new(
  :policy,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the auth policy. The auth policy is only active when the auth type is set to AWS_IAM. If you provide a policy, then authentication and authorization decisions are made based on this policy and the client's IAM policy. If the Auth type is NONE, then, any auth policy that you provide remains inactive. For more information, see Create a service network in the Amazon VPC Lattice User Guide.

Returns:

  • (String)


4110
4111
4112
4113
4114
4115
# File 'lib/aws-sdk-vpclattice/types.rb', line 4110

class PutAuthPolicyResponse < Struct.new(
  :policy,
  :state)
  SENSITIVE = []
  include Aws::Structure
end