Class: Aws::VPCLattice::Types::ResourceGatewaySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::ResourceGatewaySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Summary information about a resource gateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource gateway.
-
#created_at ⇒ Time
The date and time that the VPC endpoint association was created, in ISO-8601 format.
-
#id ⇒ String
The ID of the resource gateway.
-
#ip_address_type ⇒ String
The type of IP address used by the resource gateway.
-
#ipv4_addresses_per_eni ⇒ Integer
The number of IPv4 addresses in each ENI for the resource gateway.
-
#last_updated_at ⇒ Time
The most recent date and time that the resource gateway was updated, in ISO-8601 format.
-
#name ⇒ String
The name of the resource gateway.
-
#resource_config_dns_resolution ⇒ String
The DNS resolution type for resource configurations that are associated with this resource gateway.
-
#security_group_ids ⇒ Array<String>
The IDs of the security groups applied to the resource gateway.
-
#status ⇒ String
The name of the resource gateway.
-
#subnet_ids ⇒ Array<String>
The IDs of the VPC subnets for the resource gateway.
-
#vpc_identifier ⇒ String
The ID of the VPC for the resource gateway.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource gateway.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the VPC endpoint association was created, in ISO-8601 format.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the resource gateway.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The type of IP address used by the resource gateway.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#ipv4_addresses_per_eni ⇒ Integer
The number of IPv4 addresses in each ENI for the resource gateway.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The most recent date and time that the resource gateway was updated, in ISO-8601 format.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the resource gateway.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#resource_config_dns_resolution ⇒ String
The DNS resolution type for resource configurations that are associated with this resource gateway.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the security groups applied to the resource gateway.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The name of the resource gateway.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The IDs of the VPC subnets for the resource gateway.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#vpc_identifier ⇒ String
The ID of the VPC for the resource gateway.
4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4409 class ResourceGatewaySummary < Struct.new( :name, :id, :arn, :status, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |