Class: Aws::VPCLattice::Types::RuleMatch

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Note:

RuleMatch is a union - when making an API calls you must set exactly one of the members.

Note:

RuleMatch is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RuleMatch corresponding to the set member.

Describes a rule match.

Defined Under Namespace

Classes: HttpMatch, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#http_matchTypes::HttpMatch

The HTTP criteria that a rule must match.

Returns:



4491
4492
4493
4494
4495
4496
4497
4498
4499
4500
# File 'lib/aws-sdk-vpclattice/types.rb', line 4491

class RuleMatch < Struct.new(
  :http_match,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class HttpMatch < RuleMatch; end
  class Unknown < RuleMatch; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4491
4492
4493
# File 'lib/aws-sdk-vpclattice/types.rb', line 4491

def unknown
  @unknown
end