Class: Aws::VPCLattice::Types::ServiceNetworkResourceAssociationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Summary information about an association between a service network and a resource configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the association was created, in ISO-8601 format.

Returns:

  • (Time)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

The account that created the association.

Returns:

  • (String)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#dns_entry ⇒ Types::DnsEntry

The DNS entry for the service.

Returns:



4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#failure_code ⇒ String

The failure code.

Returns:

  • (String)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the association between the service network and resource configuration.

Returns:

  • (String)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#is_managed_association ⇒ Boolean

Specifies whether the association is managed by Amazon.

Returns:

  • (Boolean)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_enabled ⇒ Boolean

Indicates if private DNS is enabled for the service network resource association.

Returns:

  • (Boolean)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_entry ⇒ Types::DnsEntry

The private DNS entry for the service. This entry includes only the domain name.

Returns:



4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_id ⇒ String

The ID of the resource configuration associated with the service network.

Returns:

  • (String)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_name ⇒ String

The name of the resource configuration associated with the service network.

Returns:

  • (String)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_arn ⇒ String

The Amazon Resource Name (ARN) of the service network associated with the resource configuration.

Returns:

  • (String)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_id ⇒ String

The ID of the service network associated with the resource configuration.

Returns:

  • (String)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_name ⇒ String

The name of the service network associated with the resource configuration.

Returns:

  • (String)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the service network’s association with the resource configuration. If the deletion fails, try to delete again.

Returns:

  • (String)


4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-vpclattice/types.rb', line 4868

class ServiceNetworkResourceAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :resource_configuration_id,
  :resource_configuration_arn,
  :resource_configuration_name,
  :service_network_id,
  :service_network_arn,
  :service_network_name,
  :dns_entry,
  :private_dns_entry,
  :is_managed_association,
  :failure_code,
  :private_dns_enabled)
  SENSITIVE = []
  include Aws::Structure
end