Class: Aws::VPCLattice::Types::ServiceNetworkServiceAssociationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Summary information about an association between a service network and a service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the association was created, in ISO-8601 format.

Returns:

  • (Time)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

The account that created the association.

Returns:

  • (String)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#custom_domain_name ⇒ String

The custom domain name of the service.

Returns:

  • (String)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#dns_entry ⇒ Types::DnsEntry

The DNS information.

Returns:



4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the association.

Returns:

  • (String)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#service_arn ⇒ String

The Amazon Resource Name (ARN) of the service.

Returns:

  • (String)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#service_id ⇒ String

The ID of the service.

Returns:

  • (String)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#service_name ⇒ String

The name of the service.

Returns:

  • (String)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_arn ⇒ String

The Amazon Resource Name (ARN) of the service network.

Returns:

  • (String)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_id ⇒ String

The ID of the service network.

Returns:

  • (String)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_name ⇒ String

The name of the service network.

Returns:

  • (String)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the service network’s association with the service. If the deletion fails, try to delete again.

Returns:

  • (String)


4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
# File 'lib/aws-sdk-vpclattice/types.rb', line 4948

class ServiceNetworkServiceAssociationSummary < Struct.new(
  :id,
  :status,
  :arn,
  :created_by,
  :created_at,
  :service_id,
  :service_name,
  :service_arn,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :dns_entry,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end