Class: Aws::VPCLattice::Types::ServiceNetworkVpcAssociationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Summary information about an association between a service network and a VPC.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time that the association was created, in ISO-8601 format.

Returns:

  • (Time)


5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

The account that created the association.

Returns:

  • (String)


5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#dns_options ⇒ Types::DnsOptions

The DNS options for the service network VPC association.

Returns:



5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the association.

Returns:

  • (String)


5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The date and time that the association was last updated, in ISO-8601 format.

Returns:

  • (Time)


5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_enabled ⇒ Boolean

Indicates if private DNS is enabled for the service network VPC association.

Returns:

  • (Boolean)


5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_arn ⇒ String

The Amazon Resource Name (ARN) of the service network.

Returns:

  • (String)


5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_id ⇒ String

The ID of the service network.

Returns:

  • (String)


5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_network_name ⇒ String

The name of the service network.

Returns:

  • (String)


5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status.

Returns:

  • (String)


5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_id ⇒ String

The ID of the VPC.

Returns:

  • (String)


5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
# File 'lib/aws-sdk-vpclattice/types.rb', line 5074

class ServiceNetworkVpcAssociationSummary < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :created_at,
  :service_network_id,
  :service_network_name,
  :service_network_arn,
  :private_dns_enabled,
  :dns_options,
  :vpc_id,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end