Class: Aws::VPCLattice::Types::ServiceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Summary information about a service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the service.

Returns:

  • (String)


5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
# File 'lib/aws-sdk-vpclattice/types.rb', line 5040

class ServiceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the service was created, in ISO-8601 format.

Returns:

  • (Time)


5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
# File 'lib/aws-sdk-vpclattice/types.rb', line 5040

class ServiceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#custom_domain_nameString

The custom domain name of the service.

Returns:

  • (String)


5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
# File 'lib/aws-sdk-vpclattice/types.rb', line 5040

class ServiceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#dns_entryTypes::DnsEntry

The DNS information.

Returns:



5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
# File 'lib/aws-sdk-vpclattice/types.rb', line 5040

class ServiceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the service.

Returns:

  • (String)


5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
# File 'lib/aws-sdk-vpclattice/types.rb', line 5040

class ServiceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The date and time that the service was last updated, in ISO-8601 format.

Returns:

  • (Time)


5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
# File 'lib/aws-sdk-vpclattice/types.rb', line 5040

class ServiceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the service.

Returns:

  • (String)


5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
# File 'lib/aws-sdk-vpclattice/types.rb', line 5040

class ServiceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status.

Returns:

  • (String)


5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
# File 'lib/aws-sdk-vpclattice/types.rb', line 5040

class ServiceSummary < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end