Class: Aws::VPCLattice::Types::TargetGroupConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::TargetGroupConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Describes the configuration of a target group.
For more information, see [Target groups] in the *Amazon VPC Lattice User Guide*.
[1]: docs.aws.amazon.com/vpc-lattice/latest/ug/target-groups.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#health_check ⇒ Types::HealthCheckConfig
The health check configuration.
-
#ip_address_type ⇒ String
The type of IP address used for the target group.
-
#lambda_event_structure_version ⇒ String
The version of the event structure that your Lambda function receives.
-
#port ⇒ Integer
The port on which the targets are listening.
-
#protocol ⇒ String
The protocol to use for routing traffic to the targets.
-
#protocol_version ⇒ String
The protocol version.
-
#vpc_identifier ⇒ String
The ID of the VPC.
Instance Attribute Details
#health_check ⇒ Types::HealthCheckConfig
The health check configuration. Not supported if the target group type is LAMBDA or ALB.
5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5209 class TargetGroupConfig < Struct.new( :port, :protocol, :protocol_version, :ip_address_type, :vpc_identifier, :health_check, :lambda_event_structure_version) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The type of IP address used for the target group. Supported only if the target group type is IP. The default is IPV4.
5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5209 class TargetGroupConfig < Struct.new( :port, :protocol, :protocol_version, :ip_address_type, :vpc_identifier, :health_check, :lambda_event_structure_version) SENSITIVE = [] include Aws::Structure end |
#lambda_event_structure_version ⇒ String
The version of the event structure that your Lambda function receives. Supported only if the target group type is LAMBDA. The default is V1.
5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5209 class TargetGroupConfig < Struct.new( :port, :protocol, :protocol_version, :ip_address_type, :vpc_identifier, :health_check, :lambda_event_structure_version) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port on which the targets are listening. For HTTP, the default is 80. For HTTPS, the default is 443. Not supported if the target group type is LAMBDA.
5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5209 class TargetGroupConfig < Struct.new( :port, :protocol, :protocol_version, :ip_address_type, :vpc_identifier, :health_check, :lambda_event_structure_version) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocol to use for routing traffic to the targets. The default is the protocol of the target group. Not supported if the target group type is LAMBDA.
5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5209 class TargetGroupConfig < Struct.new( :port, :protocol, :protocol_version, :ip_address_type, :vpc_identifier, :health_check, :lambda_event_structure_version) SENSITIVE = [] include Aws::Structure end |
#protocol_version ⇒ String
The protocol version. The default is HTTP1. Not supported if the target group type is LAMBDA.
5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5209 class TargetGroupConfig < Struct.new( :port, :protocol, :protocol_version, :ip_address_type, :vpc_identifier, :health_check, :lambda_event_structure_version) SENSITIVE = [] include Aws::Structure end |
#vpc_identifier ⇒ String
The ID of the VPC. Not supported if the target group type is LAMBDA.
5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5209 class TargetGroupConfig < Struct.new( :port, :protocol, :protocol_version, :ip_address_type, :vpc_identifier, :health_check, :lambda_event_structure_version) SENSITIVE = [] include Aws::Structure end |