Class: Aws::VPCLattice::Types::TargetGroupSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Summary information about a target group.

For more information, see Target groups in the Amazon VPC Lattice User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN (Amazon Resource Name) of the target group.

Returns:

  • (String)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the target group was created, in ISO-8601 format.

Returns:

  • (Time)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the target group.

Returns:

  • (String)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

The type of IP address used for the target group. The possible values are IPV4 and IPV6. This is an optional parameter. If not specified, the default is IPV4.

Returns:

  • (String)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#lambda_event_structure_versionString

The version of the event structure that your Lambda function receives. Supported only if the target group type is LAMBDA.

Returns:

  • (String)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The date and time that the target group was last updated, in ISO-8601 format.

Returns:

  • (Time)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the target group.

Returns:

  • (String)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port of the target group.

Returns:

  • (Integer)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol of the target group.

Returns:

  • (String)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnsArray<String>

The Amazon Resource Names (ARNs) of the service.

Returns:

  • (Array<String>)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status.

Returns:

  • (String)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The target group type.

Returns:

  • (String)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_identifierString

The ID of the VPC of the target group.

Returns:

  • (String)


5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-vpclattice/types.rb', line 5359

class TargetGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :created_at,
  :port,
  :protocol,
  :ip_address_type,
  :vpc_identifier,
  :last_updated_at,
  :status,
  :service_arns,
  :lambda_event_structure_version)
  SENSITIVE = []
  include Aws::Structure
end