Class: Aws::VPCLattice::Types::TargetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::TargetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Summary information about a target.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the target.
-
#port ⇒ Integer
The port on which the target is listening.
-
#reason_code ⇒ String
The code for why the target status is what it is.
-
#status ⇒ String
The status of the target.
Instance Attribute Details
#id ⇒ String
The ID of the target. If the target group type is INSTANCE, this
is an instance ID. If the target group type is IP, this is an IP
address. If the target group type is LAMBDA, this is the ARN of a
Lambda function. If the target type is ALB, this is the ARN of an
Application Load Balancer.
5416 5417 5418 5419 5420 5421 5422 5423 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5416 class TargetSummary < Struct.new( :id, :port, :status, :reason_code) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port on which the target is listening.
5416 5417 5418 5419 5420 5421 5422 5423 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5416 class TargetSummary < Struct.new( :id, :port, :status, :reason_code) SENSITIVE = [] include Aws::Structure end |
#reason_code ⇒ String
The code for why the target status is what it is.
5416 5417 5418 5419 5420 5421 5422 5423 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5416 class TargetSummary < Struct.new( :id, :port, :status, :reason_code) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the target.
-
DRAINING: The target is being deregistered. No new connections are sent to this target while current connections are being drained. The default draining time is 1 minute. -
UNAVAILABLE: Health checks are unavailable for the target group. -
HEALTHY: The target is healthy. -
UNHEALTHY: The target is unhealthy. -
INITIAL: Initial health checks on the target are being performed. -
UNUSED: Target group is not used in a service.
5416 5417 5418 5419 5420 5421 5422 5423 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5416 class TargetSummary < Struct.new( :id, :port, :status, :reason_code) SENSITIVE = [] include Aws::Structure end |