Class: Aws::VPCLattice::Types::TxtMethodConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Configuration for TXT record-based domain verification method.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ String

The name of the TXT record that must be created for domain verification.

Returns:

  • (String)


5565
5566
5567
5568
5569
5570
# File 'lib/aws-sdk-vpclattice/types.rb', line 5565

class TxtMethodConfig < Struct.new(
  :value,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#value ⇒ String

The value that must be added to the TXT record for domain verification.

Returns:

  • (String)


5565
5566
5567
5568
5569
5570
# File 'lib/aws-sdk-vpclattice/types.rb', line 5565

class TxtMethodConfig < Struct.new(
  :value,
  :name)
  SENSITIVE = []
  include Aws::Structure
end