Class: Aws::VPCLattice::Types::UpdateServiceNetworkVpcAssociationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
# File 'lib/aws-sdk-vpclattice/types.rb', line 6081

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

The account that created the association.

Returns:

  • (String)


6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
# File 'lib/aws-sdk-vpclattice/types.rb', line 6081

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#dns_options ⇒ Types::DnsOptions

DNS options for the service network VPC association.

Returns:



6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
# File 'lib/aws-sdk-vpclattice/types.rb', line 6081

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the association.

Returns:

  • (String)


6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
# File 'lib/aws-sdk-vpclattice/types.rb', line 6081

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_enabled ⇒ Boolean

Indicates if private DNS is enabled for the VPC association.

Returns:

  • (Boolean)


6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
# File 'lib/aws-sdk-vpclattice/types.rb', line 6081

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_ids ⇒ Array<String>

The IDs of the security groups.

Returns:

  • (Array<String>)


6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
# File 'lib/aws-sdk-vpclattice/types.rb', line 6081

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status. You can retry the operation if the status is DELETE_FAILED. However, if you retry it while the status is DELETE_IN_PROGRESS, there is no change in the status.

Returns:

  • (String)


6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
# File 'lib/aws-sdk-vpclattice/types.rb', line 6081

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end