Class: Aws::VPCLattice::Types::UpdateServiceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_typeString

The type of IAM policy.

  • NONE: The resource does not use an IAM policy. This is the default.

  • AWS_IAM: The resource uses an IAM policy. When this type is used, auth is enabled and an auth policy is required.

Returns:

  • (String)


6001
6002
6003
6004
6005
6006
6007
6008
# File 'lib/aws-sdk-vpclattice/types.rb', line 6001

class UpdateServiceRequest < Struct.new(
  :service_identifier,
  :certificate_arn,
  :auth_type,
  :idle_timeout_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_arnString

The Amazon Resource Name (ARN) of the certificate.

Returns:

  • (String)


6001
6002
6003
6004
6005
6006
6007
6008
# File 'lib/aws-sdk-vpclattice/types.rb', line 6001

class UpdateServiceRequest < Struct.new(
  :service_identifier,
  :certificate_arn,
  :auth_type,
  :idle_timeout_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#idle_timeout_secondsInteger

The amount of time, in seconds, that a connection can remain idle (no data sent) before VPC Lattice closes it. The valid range is 60 to 600 seconds. If you don't specify a value, the default is 60 seconds. This setting does not change the maximum connection duration of 10 minutes; connections are still closed when they reach that limit.

Returns:

  • (Integer)


6001
6002
6003
6004
6005
6006
6007
6008
# File 'lib/aws-sdk-vpclattice/types.rb', line 6001

class UpdateServiceRequest < Struct.new(
  :service_identifier,
  :certificate_arn,
  :auth_type,
  :idle_timeout_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#service_identifierString

The ID or ARN of the service.

Returns:

  • (String)


6001
6002
6003
6004
6005
6006
6007
6008
# File 'lib/aws-sdk-vpclattice/types.rb', line 6001

class UpdateServiceRequest < Struct.new(
  :service_identifier,
  :certificate_arn,
  :auth_type,
  :idle_timeout_seconds)
  SENSITIVE = []
  include Aws::Structure
end