Class: Aws::VPCLattice::Types::CreateResourceGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::CreateResourceGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#ip_address_type ⇒ String
A resource gateway can have IPv4, IPv6 or dualstack addresses.
-
#ipv4_addresses_per_eni ⇒ Integer
The number of IPv4 addresses in each ENI for the resource gateway.
-
#name ⇒ String
The name of the resource gateway.
-
#resource_config_dns_resolution ⇒ String
Indicates how DNS is resolved for resource configurations associated to this resource gateway.
-
#security_group_ids ⇒ Array<String>
The IDs of the security groups to apply to the resource gateway.
-
#subnet_ids ⇒ Array<String>
The IDs of the VPC subnets in which to create the resource gateway.
-
#tags ⇒ Hash<String,String>
The tags for the resource gateway.
-
#vpc_identifier ⇒ String
The ID of the VPC for the resource gateway.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token and parameters, the retry succeeds without performing any actions. If the parameters aren’t identical, the retry fails.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 651 class CreateResourceGatewayRequest < Struct.new( :client_token, :name, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :tags) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
A resource gateway can have IPv4, IPv6 or dualstack addresses. The IP address type of a resource gateway must be compatible with the subnets of the resource gateway and the IP address type of the resource, as described here:
-
**IPv4**Assign IPv4 addresses to your resource gateway network interfaces. This option is supported only if all selected subnets have IPv4 address ranges, and the resource also has an IPv4 address.
-
**IPv6**Assign IPv6 addresses to your resource gateway network interfaces. This option is supported only if all selected subnets are IPv6 only subnets, and the resource also has an IPv6 address.
-
**Dualstack**Assign both IPv4 and IPv6 addresses to your resource gateway network interfaces. This option is supported only if all selected subnets have both IPv4 and IPv6 address ranges, and the resource either has an IPv4 or IPv6 address.
The IP address type of the resource gateway is independent of the IP address type of the client or the VPC endpoint through which the resource is accessed.
651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 651 class CreateResourceGatewayRequest < Struct.new( :client_token, :name, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :tags) SENSITIVE = [] include Aws::Structure end |
#ipv4_addresses_per_eni ⇒ Integer
The number of IPv4 addresses in each ENI for the resource gateway.
651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 651 class CreateResourceGatewayRequest < Struct.new( :client_token, :name, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the resource gateway.
651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 651 class CreateResourceGatewayRequest < Struct.new( :client_token, :name, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_config_dns_resolution ⇒ String
Indicates how DNS is resolved for resource configurations associated to this resource gateway. ResourceConfigDnsResolution is set at creation time and cannot be changed.
-
‘IN_VPC` - DNS resolution occurs privately within the resource gateway’s VPC. DNS queries for resources behind this resource gateway resolve using the DNS resolvers defined in the VPC’s DHCP option sets. Use this when your resource domain names are hosted in private Route 53 hosted zones or on-premises DNS servers reachable from the VPC.
-
‘PUBLIC` - DNS resolution occurs against public DNS resolvers. DNS queries for resources behind this resource gateway resolve using standard public DNS. Use this when your resource domain names are publicly resolvable.
651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 651 class CreateResourceGatewayRequest < Struct.new( :client_token, :name, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :tags) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the security groups to apply to the resource gateway. The security groups must be in the same VPC.
651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 651 class CreateResourceGatewayRequest < Struct.new( :client_token, :name, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :tags) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The IDs of the VPC subnets in which to create the resource gateway.
651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 651 class CreateResourceGatewayRequest < Struct.new( :client_token, :name, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags for the resource gateway.
651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 651 class CreateResourceGatewayRequest < Struct.new( :client_token, :name, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_identifier ⇒ String
The ID of the VPC for the resource gateway.
651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 651 class CreateResourceGatewayRequest < Struct.new( :client_token, :name, :vpc_identifier, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :tags) SENSITIVE = [] include Aws::Structure end |