Class: Aws::VPCLattice::Types::CreateServiceNetworkVpcAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::CreateServiceNetworkVpcAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dns_options ⇒ Types::DnsOptions
DNS options for the service network VPC association.
-
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled for the VPC association.
-
#security_group_ids ⇒ Array<String>
The IDs of the security groups.
-
#service_network_identifier ⇒ String
The ID or ARN of the service network.
-
#tags ⇒ Hash<String,String>
The tags for the association.
-
#vpc_identifier ⇒ String
The ID of the VPC.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token and parameters, the retry succeeds without performing any actions. If the parameters aren’t identical, the retry fails.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1096 class CreateServiceNetworkVpcAssociationRequest < Struct.new( :client_token, :service_network_identifier, :vpc_identifier, :private_dns_enabled, :security_group_ids, :tags, :dns_options) SENSITIVE = [] include Aws::Structure end |
#dns_options ⇒ Types::DnsOptions
DNS options for the service network VPC association.
1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1096 class CreateServiceNetworkVpcAssociationRequest < Struct.new( :client_token, :service_network_identifier, :vpc_identifier, :private_dns_enabled, :security_group_ids, :tags, :dns_options) SENSITIVE = [] include Aws::Structure end |
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled for the VPC association.
1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1096 class CreateServiceNetworkVpcAssociationRequest < Struct.new( :client_token, :service_network_identifier, :vpc_identifier, :private_dns_enabled, :security_group_ids, :tags, :dns_options) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the security groups. Security groups aren’t added by default. You can add a security group to apply network level controls to control which resources in a VPC are allowed to access the service network and its services. For more information, see
- Control traffic to resources using security groups][1
-
in the
*Amazon VPC User Guide*.
[1]: docs.aws.amazon.com/vpc/latest/userguide/VPC_SecurityGroups.html
1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1096 class CreateServiceNetworkVpcAssociationRequest < Struct.new( :client_token, :service_network_identifier, :vpc_identifier, :private_dns_enabled, :security_group_ids, :tags, :dns_options) SENSITIVE = [] include Aws::Structure end |
#service_network_identifier ⇒ String
The ID or ARN of the service network. You must use an ARN if the resources are in different accounts.
1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1096 class CreateServiceNetworkVpcAssociationRequest < Struct.new( :client_token, :service_network_identifier, :vpc_identifier, :private_dns_enabled, :security_group_ids, :tags, :dns_options) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags for the association.
1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1096 class CreateServiceNetworkVpcAssociationRequest < Struct.new( :client_token, :service_network_identifier, :vpc_identifier, :private_dns_enabled, :security_group_ids, :tags, :dns_options) SENSITIVE = [] include Aws::Structure end |
#vpc_identifier ⇒ String
The ID of the VPC.
1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 1096 class CreateServiceNetworkVpcAssociationRequest < Struct.new( :client_token, :service_network_identifier, :vpc_identifier, :private_dns_enabled, :security_group_ids, :tags, :dns_options) SENSITIVE = [] include Aws::Structure end |