Class: Aws::VPCLattice::Types::DeleteServiceNetworkVpcAssociationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-vpclattice/types.rb', line 1674

class DeleteServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the association.

Returns:

  • (String)


1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-vpclattice/types.rb', line 1674

class DeleteServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status. You can retry the operation if the status is DELETE_FAILED. However, if you retry it while the status is DELETE_IN_PROGRESS, there is no change in the status.

Returns:

  • (String)


1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-vpclattice/types.rb', line 1674

class DeleteServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :status,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end