Class: Aws::VPCLattice::Types::DeleteServiceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the service.

Returns:

  • (String)


1714
1715
1716
1717
1718
1719
1720
1721
# File 'lib/aws-sdk-vpclattice/types.rb', line 1714

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the service.

Returns:

  • (String)


1714
1715
1716
1717
1718
1719
1720
1721
# File 'lib/aws-sdk-vpclattice/types.rb', line 1714

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the service.

Returns:

  • (String)


1714
1715
1716
1717
1718
1719
1720
1721
# File 'lib/aws-sdk-vpclattice/types.rb', line 1714

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status. You can retry the operation if the status is DELETE_FAILED. However, if you retry it while the status is DELETE_IN_PROGRESS, the status doesn't change.

Returns:

  • (String)


1714
1715
1716
1717
1718
1719
1720
1721
# File 'lib/aws-sdk-vpclattice/types.rb', line 1714

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end