Class: Aws::VPCLattice::Types::DeleteServiceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the service.

Returns:

  • (String)


1698
1699
1700
1701
1702
1703
1704
1705
# File 'lib/aws-sdk-vpclattice/types.rb', line 1698

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the service.

Returns:

  • (String)


1698
1699
1700
1701
1702
1703
1704
1705
# File 'lib/aws-sdk-vpclattice/types.rb', line 1698

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the service.

Returns:

  • (String)


1698
1699
1700
1701
1702
1703
1704
1705
# File 'lib/aws-sdk-vpclattice/types.rb', line 1698

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status. You can retry the operation if the status is ‘DELETE_FAILED`. However, if you retry it while the status is `DELETE_IN_PROGRESS`, the status doesn’t change.

Returns:

  • (String)


1698
1699
1700
1701
1702
1703
1704
1705
# File 'lib/aws-sdk-vpclattice/types.rb', line 1698

class DeleteServiceResponse < Struct.new(
  :id,
  :arn,
  :name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end