Class: Aws::VPCLattice::Types::GetDomainVerificationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the domain verification.

Returns:

  • (String)


2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
# File 'lib/aws-sdk-vpclattice/types.rb', line 2109

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the domain verification was created, in ISO-8601 format.

Returns:

  • (Time)


2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
# File 'lib/aws-sdk-vpclattice/types.rb', line 2109

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The domain name being verified.

Returns:

  • (String)


2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
# File 'lib/aws-sdk-vpclattice/types.rb', line 2109

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the domain verification.

Returns:

  • (String)


2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
# File 'lib/aws-sdk-vpclattice/types.rb', line 2109

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_verified_timeTime

The date and time that the domain was last successfully verified, in ISO-8601 format.

Returns:

  • (Time)


2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
# File 'lib/aws-sdk-vpclattice/types.rb', line 2109

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the domain verification process.

Returns:

  • (String)


2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
# File 'lib/aws-sdk-vpclattice/types.rb', line 2109

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags associated with the domain verification.

Returns:

  • (Hash<String,String>)


2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
# File 'lib/aws-sdk-vpclattice/types.rb', line 2109

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#txt_method_configTypes::TxtMethodConfig

The TXT record configuration used for domain verification.



2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
# File 'lib/aws-sdk-vpclattice/types.rb', line 2109

class GetDomainVerificationResponse < Struct.new(
  :id,
  :arn,
  :domain_name,
  :status,
  :txt_method_config,
  :created_at,
  :last_verified_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end