Class: Aws::VPCLattice::Types::GetResourceConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::GetResourceConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_association_to_shareable_service_network ⇒ Boolean
Specifies whether the resource configuration is associated with a sharable service network.
-
#amazon_managed ⇒ Boolean
Indicates whether the resource configuration was created and is managed by Amazon.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource configuration.
-
#created_at ⇒ Time
The date and time that the resource configuration was created, in ISO-8601 format.
-
#custom_domain_name ⇒ String
The custom domain name of the resource configuration.
-
#domain_verification_arn ⇒ String
The ARN of the domain verification.
-
#domain_verification_id ⇒ String
The domain verification ID.
-
#domain_verification_status ⇒ String
The domain verification status.
-
#failure_reason ⇒ String
The reason the create-resource-configuration request failed.
-
#group_domain ⇒ String
(GROUP) The group domain for a group resource configuration.
-
#id ⇒ String
The ID of the resource configuration.
-
#last_updated_at ⇒ Time
The most recent date and time that the resource configuration was updated, in ISO-8601 format.
-
#name ⇒ String
The name of the resource configuration.
-
#port_ranges ⇒ Array<String>
The TCP port ranges that a consumer can use to access a resource configuration.
-
#protocol ⇒ String
The TCP protocol accepted by the specified resource configuration.
-
#resource_configuration_definition ⇒ Types::ResourceConfigurationDefinition
The resource configuration.
-
#resource_configuration_group_id ⇒ String
The ID of the group resource configuration.
-
#resource_gateway_id ⇒ String
The ID of the resource gateway used to connect to the resource configuration in a given VPC.
-
#status ⇒ String
The status of the resource configuration.
-
#type ⇒ String
The type of resource configuration.
Instance Attribute Details
#allow_association_to_shareable_service_network ⇒ Boolean
Specifies whether the resource configuration is associated with a sharable service network.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#amazon_managed ⇒ Boolean
Indicates whether the resource configuration was created and is managed by Amazon.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource configuration.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the resource configuration was created, in ISO-8601 format.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#custom_domain_name ⇒ String
The custom domain name of the resource configuration.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#domain_verification_arn ⇒ String
The ARN of the domain verification.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#domain_verification_id ⇒ String
The domain verification ID.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#domain_verification_status ⇒ String
The domain verification status.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason the create-resource-configuration request failed.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#group_domain ⇒ String
(GROUP) The group domain for a group resource configuration. Any domains that you create for the child resource are subdomains of the group domain. Child resources inherit the verification status of the domain.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the resource configuration.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The most recent date and time that the resource configuration was updated, in ISO-8601 format.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the resource configuration.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#port_ranges ⇒ Array<String>
The TCP port ranges that a consumer can use to access a resource configuration. You can separate port ranges with a comma. Example: 1-65535 or 1,2,22-30
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The TCP protocol accepted by the specified resource configuration.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_definition ⇒ Types::ResourceConfigurationDefinition
The resource configuration.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_group_id ⇒ String
The ID of the group resource configuration.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#resource_gateway_id ⇒ String
The ID of the resource gateway used to connect to the resource configuration in a given VPC. You can specify the resource gateway identifier only for resource configurations with type SINGLE, GROUP, or ARN.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the resource configuration.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of resource configuration.
-
‘SINGLE` - A single resource.
-
‘GROUP` - A group of resources.
-
‘CHILD` - A single resource that is part of a group resource configuration.
-
‘ARN` - An Amazon Web Services resource.
2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2312 class GetResourceConfigurationResponse < Struct.new( :id, :name, :arn, :resource_gateway_id, :resource_configuration_group_id, :type, :allow_association_to_shareable_service_network, :port_ranges, :protocol, :custom_domain_name, :status, :resource_configuration_definition, :created_at, :amazon_managed, :failure_reason, :last_updated_at, :domain_verification_id, :domain_verification_arn, :domain_verification_status, :group_domain) SENSITIVE = [] include Aws::Structure end |