Class: Aws::VPCLattice::Types::GetResourceGatewayResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the resource gateway.

Returns:

  • (String)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the resource gateway was created, in ISO-8601 format.

Returns:

  • (Time)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the resource gateway.

Returns:

  • (String)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

The type of IP address for the resource gateway.

Returns:

  • (String)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#ipv4_addresses_per_eniInteger

The number of IPv4 addresses in each ENI for the resource gateway.

Returns:

  • (Integer)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The date and time that the resource gateway was last updated, in ISO-8601 format.

Returns:

  • (Time)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#managed_byString

The AWS service that manages the resource gateway.

Returns:

  • (String)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the resource gateway.

Returns:

  • (String)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#resource_config_dns_resolutionString

The DNS resolution type for resource configurations that are associated with this resource gateway.

Returns:

  • (String)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The security group IDs associated with the resource gateway.

Returns:

  • (Array<String>)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_managedBoolean

Indicates whether the resource gateway is managed by an AWS service.

Returns:

  • (Boolean)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status for the resource gateway.

Returns:

  • (String)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The IDs of the VPC subnets for resource gateway.

Returns:

  • (Array<String>)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC for the resource gateway.

Returns:

  • (String)


2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410

class GetResourceGatewayResponse < Struct.new(
  :name,
  :id,
  :arn,
  :status,
  :vpc_id,
  :subnet_ids,
  :service_managed,
  :managed_by,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :resource_config_dns_resolution,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end