Class: Aws::VPCLattice::Types::GetResourceGatewayResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::GetResourceGatewayResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource gateway.
-
#created_at ⇒ Time
The date and time that the resource gateway was created, in ISO-8601 format.
-
#id ⇒ String
The ID of the resource gateway.
-
#ip_address_type ⇒ String
The type of IP address for the resource gateway.
-
#ipv4_addresses_per_eni ⇒ Integer
The number of IPv4 addresses in each ENI for the resource gateway.
-
#last_updated_at ⇒ Time
The date and time that the resource gateway was last updated, in ISO-8601 format.
-
#managed_by ⇒ String
The AWS service that manages the resource gateway.
-
#name ⇒ String
The name of the resource gateway.
-
#resource_config_dns_resolution ⇒ String
The DNS resolution type for resource configurations that are associated with this resource gateway.
-
#security_group_ids ⇒ Array<String>
The security group IDs associated with the resource gateway.
-
#service_managed ⇒ Boolean
Indicates whether the resource gateway is managed by an AWS service.
-
#status ⇒ String
The status for the resource gateway.
-
#subnet_ids ⇒ Array<String>
The IDs of the VPC subnets for resource gateway.
-
#vpc_id ⇒ String
The ID of the VPC for the resource gateway.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource gateway.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the resource gateway was created, in ISO-8601 format.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the resource gateway.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The type of IP address for the resource gateway.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#ipv4_addresses_per_eni ⇒ Integer
The number of IPv4 addresses in each ENI for the resource gateway.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The date and time that the resource gateway was last updated, in ISO-8601 format.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#managed_by ⇒ String
The AWS service that manages the resource gateway.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the resource gateway.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#resource_config_dns_resolution ⇒ String
The DNS resolution type for resource configurations that are associated with this resource gateway.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The security group IDs associated with the resource gateway.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#service_managed ⇒ Boolean
Indicates whether the resource gateway is managed by an AWS service.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status for the resource gateway.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The IDs of the VPC subnets for resource gateway.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC for the resource gateway.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2410 class GetResourceGatewayResponse < Struct.new( :name, :id, :arn, :status, :vpc_id, :subnet_ids, :service_managed, :managed_by, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :resource_config_dns_resolution, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |