Class: Aws::VPCLattice::Types::GetServiceNetworkResourceAssociationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::GetServiceNetworkResourceAssociationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
-
#created_at ⇒ Time
The date and time that the association was created, in ISO-8601 format.
-
#created_by ⇒ String
The account that created the association.
-
#dns_entry ⇒ Types::DnsEntry
The DNS entry for the service.
-
#domain_verification_status ⇒ String
The domain verification status in the service network resource association.
-
#failure_code ⇒ String
The failure code.
-
#failure_reason ⇒ String
The reason the association request failed.
-
#id ⇒ String
The ID of the association.
-
#is_managed_association ⇒ Boolean
Indicates whether the association is managed by Amazon.
-
#last_updated_at ⇒ Time
The most recent date and time that the association was updated, in ISO-8601 format.
-
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled in the service network resource association.
-
#private_dns_entry ⇒ Types::DnsEntry
The private DNS entry for the service.
-
#resource_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the association.
-
#resource_configuration_id ⇒ String
The ID of the resource configuration that is associated with the service network.
-
#resource_configuration_name ⇒ String
The name of the resource configuration that is associated with the service network.
-
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network that is associated with the resource configuration.
-
#service_network_id ⇒ String
The ID of the service network that is associated with the resource configuration.
-
#service_network_name ⇒ String
The name of the service network that is associated with the resource configuration.
-
#status ⇒ String
The status of the association.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the association was created, in ISO-8601 format.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The account that created the association.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#dns_entry ⇒ Types::DnsEntry
The DNS entry for the service.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#domain_verification_status ⇒ String
The domain verification status in the service network resource association.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
The failure code.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason the association request failed.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the association.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#is_managed_association ⇒ Boolean
Indicates whether the association is managed by Amazon.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The most recent date and time that the association was updated, in ISO-8601 format.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled in the service network resource association.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#private_dns_entry ⇒ Types::DnsEntry
The private DNS entry for the service.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the association.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_id ⇒ String
The ID of the resource configuration that is associated with the service network.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_name ⇒ String
The name of the resource configuration that is associated with the service network.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network that is associated with the resource configuration.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#service_network_id ⇒ String
The ID of the service network that is associated with the resource configuration.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#service_network_name ⇒ String
The name of the service network that is associated with the resource configuration.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the association.
2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2657 class GetServiceNetworkResourceAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :failure_reason, :failure_code, :last_updated_at, :private_dns_entry, :private_dns_enabled, :dns_entry, :is_managed_association, :domain_verification_status) SENSITIVE = [] include Aws::Structure end |