Class: Aws::VPCLattice::Types::GetServiceNetworkResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the service network.

Returns:

  • (String)


2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
# File 'lib/aws-sdk-vpclattice/types.rb', line 2720

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#auth_typeString

The type of IAM policy.

Returns:

  • (String)


2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
# File 'lib/aws-sdk-vpclattice/types.rb', line 2720

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the service network was created, in ISO-8601 format.

Returns:

  • (Time)


2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
# File 'lib/aws-sdk-vpclattice/types.rb', line 2720

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the service network.

Returns:

  • (String)


2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
# File 'lib/aws-sdk-vpclattice/types.rb', line 2720

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The date and time of the last update, in ISO-8601 format.

Returns:

  • (Time)


2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
# File 'lib/aws-sdk-vpclattice/types.rb', line 2720

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the service network.

Returns:

  • (String)


2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
# File 'lib/aws-sdk-vpclattice/types.rb', line 2720

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_associated_servicesInteger

The number of services associated with the service network.

Returns:

  • (Integer)


2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
# File 'lib/aws-sdk-vpclattice/types.rb', line 2720

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_associated_vp_csInteger

The number of VPCs associated with the service network.

Returns:

  • (Integer)


2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
# File 'lib/aws-sdk-vpclattice/types.rb', line 2720

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end

#sharing_configTypes::SharingConfig

Specifies if the service network is enabled for sharing.



2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
# File 'lib/aws-sdk-vpclattice/types.rb', line 2720

class GetServiceNetworkResponse < Struct.new(
  :id,
  :name,
  :created_at,
  :last_updated_at,
  :arn,
  :auth_type,
  :sharing_config,
  :number_of_associated_vp_cs,
  :number_of_associated_services)
  SENSITIVE = []
  include Aws::Structure
end