Class: Aws::VPCLattice::Types::GetServiceNetworkVpcAssociationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::GetServiceNetworkVpcAssociationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
-
#created_at ⇒ Time
The date and time that the association was created, in ISO-8601 format.
-
#created_by ⇒ String
The account that created the association.
-
#dns_options ⇒ Types::DnsOptions
DNS options for the service network VPC association.
-
#failure_code ⇒ String
The failure code.
-
#failure_message ⇒ String
The failure message.
-
#id ⇒ String
The ID of the association.
-
#last_updated_at ⇒ Time
The date and time that the association was last updated, in ISO-8601 format.
-
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled in the VPC association.
-
#security_group_ids ⇒ Array<String>
The IDs of the security groups.
-
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
-
#service_network_id ⇒ String
The ID of the service network.
-
#service_network_name ⇒ String
The name of the service network.
-
#status ⇒ String
The status of the association.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the association was created, in ISO-8601 format.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The account that created the association.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#dns_options ⇒ Types::DnsOptions
DNS options for the service network VPC association.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
The failure code.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
The failure message.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the association.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The date and time that the association was last updated, in ISO-8601 format.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled in the VPC association.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the security groups.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#service_network_id ⇒ String
The ID of the service network.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#service_network_name ⇒ String
The name of the service network.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the association.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2905 class GetServiceNetworkVpcAssociationResponse < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :vpc_id, :security_group_ids, :private_dns_enabled, :failure_message, :failure_code, :last_updated_at, :dns_options) SENSITIVE = [] include Aws::Structure end |