Class: Aws::VPCLattice::Types::GetServiceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the service.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#auth_typeString

The type of IAM policy.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_arnString

The Amazon Resource Name (ARN) of the certificate.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the service was created, in ISO-8601 format.

Returns:

  • (Time)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#custom_domain_nameString

The custom domain name of the service.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#dns_entryTypes::DnsEntry

The DNS name of the service.

Returns:



2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#failure_codeString

The failure code.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

The failure message.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the service.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#idle_timeout_secondsInteger

The amount of time, in seconds, that a connection can remain idle before VPC Lattice closes it.

Returns:

  • (Integer)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The date and time that the service was last updated, in ISO-8601 format.

Returns:

  • (Time)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the service.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the service.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
# File 'lib/aws-sdk-vpclattice/types.rb', line 2993

class GetServiceResponse < Struct.new(
  :id,
  :name,
  :arn,
  :created_at,
  :last_updated_at,
  :dns_entry,
  :custom_domain_name,
  :certificate_arn,
  :status,
  :auth_type,
  :idle_timeout_seconds,
  :failure_code,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end