Class: Aws::VPCLattice::Types::GetServiceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::GetServiceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the service.
-
#auth_type ⇒ String
The type of IAM policy.
-
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate.
-
#created_at ⇒ Time
The date and time that the service was created, in ISO-8601 format.
-
#custom_domain_name ⇒ String
The custom domain name of the service.
-
#dns_entry ⇒ Types::DnsEntry
The DNS name of the service.
-
#failure_code ⇒ String
The failure code.
-
#failure_message ⇒ String
The failure message.
-
#id ⇒ String
The ID of the service.
-
#last_updated_at ⇒ Time
The date and time that the service was last updated, in ISO-8601 format.
-
#name ⇒ String
The name of the service.
-
#status ⇒ String
The status of the service.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the service.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#auth_type ⇒ String
The type of IAM policy.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the service was created, in ISO-8601 format.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#custom_domain_name ⇒ String
The custom domain name of the service.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#dns_entry ⇒ Types::DnsEntry
The DNS name of the service.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
The failure code.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
The failure message.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the service.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The date and time that the service was last updated, in ISO-8601 format.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the service.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the service.
2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 2971 class GetServiceResponse < Struct.new( :id, :name, :arn, :created_at, :last_updated_at, :dns_entry, :custom_domain_name, :certificate_arn, :status, :auth_type, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |