Class: Aws::VPCLattice::Types::GetTargetGroupResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::GetTargetGroupResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the target group.
-
#config ⇒ Types::TargetGroupConfig
The target group configuration.
-
#created_at ⇒ Time
The date and time that the target group was created, in ISO-8601 format.
-
#failure_code ⇒ String
The failure code.
-
#failure_message ⇒ String
The failure message.
-
#id ⇒ String
The ID of the target group.
-
#last_updated_at ⇒ Time
The date and time that the target group was last updated, in ISO-8601 format.
-
#name ⇒ String
The name of the target group.
-
#service_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the service.
-
#status ⇒ String
The status.
-
#type ⇒ String
The target group type.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the target group.
3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3071 class GetTargetGroupResponse < Struct.new( :id, :arn, :name, :type, :config, :created_at, :last_updated_at, :status, :service_arns, :failure_message, :failure_code) SENSITIVE = [] include Aws::Structure end |
#config ⇒ Types::TargetGroupConfig
The target group configuration.
3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3071 class GetTargetGroupResponse < Struct.new( :id, :arn, :name, :type, :config, :created_at, :last_updated_at, :status, :service_arns, :failure_message, :failure_code) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the target group was created, in ISO-8601 format.
3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3071 class GetTargetGroupResponse < Struct.new( :id, :arn, :name, :type, :config, :created_at, :last_updated_at, :status, :service_arns, :failure_message, :failure_code) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
The failure code.
3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3071 class GetTargetGroupResponse < Struct.new( :id, :arn, :name, :type, :config, :created_at, :last_updated_at, :status, :service_arns, :failure_message, :failure_code) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
The failure message.
3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3071 class GetTargetGroupResponse < Struct.new( :id, :arn, :name, :type, :config, :created_at, :last_updated_at, :status, :service_arns, :failure_message, :failure_code) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the target group.
3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3071 class GetTargetGroupResponse < Struct.new( :id, :arn, :name, :type, :config, :created_at, :last_updated_at, :status, :service_arns, :failure_message, :failure_code) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The date and time that the target group was last updated, in ISO-8601 format.
3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3071 class GetTargetGroupResponse < Struct.new( :id, :arn, :name, :type, :config, :created_at, :last_updated_at, :status, :service_arns, :failure_message, :failure_code) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the target group.
3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3071 class GetTargetGroupResponse < Struct.new( :id, :arn, :name, :type, :config, :created_at, :last_updated_at, :status, :service_arns, :failure_message, :failure_code) SENSITIVE = [] include Aws::Structure end |
#service_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the service.
3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3071 class GetTargetGroupResponse < Struct.new( :id, :arn, :name, :type, :config, :created_at, :last_updated_at, :status, :service_arns, :failure_message, :failure_code) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status.
3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3071 class GetTargetGroupResponse < Struct.new( :id, :arn, :name, :type, :config, :created_at, :last_updated_at, :status, :service_arns, :failure_message, :failure_code) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The target group type.
3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 3071 class GetTargetGroupResponse < Struct.new( :id, :arn, :name, :type, :config, :created_at, :last_updated_at, :status, :service_arns, :failure_message, :failure_code) SENSITIVE = [] include Aws::Structure end |