Class: Aws::VPCLattice::Types::GetTargetGroupResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the target group.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#configTypes::TargetGroupConfig

The target group configuration.



3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the target group was created, in ISO-8601 format.

Returns:

  • (Time)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#failure_codeString

The failure code.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

The failure message.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the target group.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The date and time that the target group was last updated, in ISO-8601 format.

Returns:

  • (Time)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the target group.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnsArray<String>

The Amazon Resource Names (ARNs) of the service.

Returns:

  • (Array<String>)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The target group type.

Returns:

  • (String)


3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
# File 'lib/aws-sdk-vpclattice/types.rb', line 3048

class GetTargetGroupResponse < Struct.new(
  :id,
  :arn,
  :name,
  :type,
  :config,
  :created_at,
  :last_updated_at,
  :status,
  :service_arns,
  :failure_message,
  :failure_code)
  SENSITIVE = []
  include Aws::Structure
end