Class: Aws::VPCLattice::Types::PutAuthPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::PutAuthPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy ⇒ String
The auth policy.
-
#resource_identifier ⇒ String
The ID or ARN of the service network or service for which the policy is created.
Instance Attribute Details
#policy ⇒ String
The auth policy. The policy string in JSON must not contain newlines or blank lines.
4059 4060 4061 4062 4063 4064 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4059 class PutAuthPolicyRequest < Struct.new( :resource_identifier, :policy) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ String
The ID or ARN of the service network or service for which the policy is created.
4059 4060 4061 4062 4063 4064 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4059 class PutAuthPolicyRequest < Struct.new( :resource_identifier, :policy) SENSITIVE = [] include Aws::Structure end |