Class: Aws::VPCLattice::Types::ServiceNetworkResourceAssociationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::ServiceNetworkResourceAssociationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Summary information about an association between a service network and a resource configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
-
#created_at ⇒ Time
The date and time that the association was created, in ISO-8601 format.
-
#created_by ⇒ String
The account that created the association.
-
#dns_entry ⇒ Types::DnsEntry
The DNS entry for the service.
-
#failure_code ⇒ String
The failure code.
-
#id ⇒ String
The ID of the association between the service network and resource configuration.
-
#is_managed_association ⇒ Boolean
Specifies whether the association is managed by Amazon.
-
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled for the service network resource association.
-
#private_dns_entry ⇒ Types::DnsEntry
The private DNS entry for the service.
-
#resource_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the association.
-
#resource_configuration_id ⇒ String
The ID of the resource configuration associated with the service network.
-
#resource_configuration_name ⇒ String
The name of the resource configuration associated with the service network.
-
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network associated with the resource configuration.
-
#service_network_id ⇒ String
The ID of the service network associated with the resource configuration.
-
#service_network_name ⇒ String
The name of the service network associated with the resource configuration.
-
#status ⇒ String
The status of the service network’s association with the resource configuration.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the association was created, in ISO-8601 format.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The account that created the association.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#dns_entry ⇒ Types::DnsEntry
The DNS entry for the service.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
The failure code.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the association between the service network and resource configuration.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#is_managed_association ⇒ Boolean
Specifies whether the association is managed by Amazon.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled for the service network resource association.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#private_dns_entry ⇒ Types::DnsEntry
The private DNS entry for the service.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the association.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_id ⇒ String
The ID of the resource configuration associated with the service network.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_name ⇒ String
The name of the resource configuration associated with the service network.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network associated with the resource configuration.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#service_network_id ⇒ String
The ID of the service network associated with the resource configuration.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#service_network_name ⇒ String
The name of the service network associated with the resource configuration.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the service network’s association with the resource configuration. If the deletion fails, try to delete again.
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4770 class ServiceNetworkResourceAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :resource_configuration_id, :resource_configuration_arn, :resource_configuration_name, :service_network_id, :service_network_arn, :service_network_name, :dns_entry, :private_dns_entry, :is_managed_association, :failure_code, :private_dns_enabled) SENSITIVE = [] include Aws::Structure end |