Class: Aws::VPCLattice::Types::ServiceNetworkServiceAssociationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::ServiceNetworkServiceAssociationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Summary information about an association between a service network and a service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
-
#created_at ⇒ Time
The date and time that the association was created, in ISO-8601 format.
-
#created_by ⇒ String
The account that created the association.
-
#custom_domain_name ⇒ String
The custom domain name of the service.
-
#dns_entry ⇒ Types::DnsEntry
The DNS information.
-
#id ⇒ String
The ID of the association.
-
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the service.
-
#service_id ⇒ String
The ID of the service.
-
#service_name ⇒ String
The name of the service.
-
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
-
#service_network_id ⇒ String
The ID of the service network.
-
#service_network_name ⇒ String
The name of the service network.
-
#status ⇒ String
The status of the service network’s association with the service.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the association was created, in ISO-8601 format.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The account that created the association.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#custom_domain_name ⇒ String
The custom domain name of the service.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#dns_entry ⇒ Types::DnsEntry
The DNS information.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the association.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the service.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#service_id ⇒ String
The ID of the service.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the service.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#service_network_id ⇒ String
The ID of the service network.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#service_network_name ⇒ String
The name of the service network.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the service network’s association with the service. If the deletion fails, try to delete again.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4850 class ServiceNetworkServiceAssociationSummary < Struct.new( :id, :status, :arn, :created_by, :created_at, :service_id, :service_name, :service_arn, :service_network_id, :service_network_name, :service_network_arn, :dns_entry, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |