Class: Aws::VPCLattice::Types::ServiceNetworkVpcAssociationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::ServiceNetworkVpcAssociationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Summary information about an association between a service network and a VPC.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
-
#created_at ⇒ Time
The date and time that the association was created, in ISO-8601 format.
-
#created_by ⇒ String
The account that created the association.
-
#dns_options ⇒ Types::DnsOptions
The DNS options for the service network VPC association.
-
#id ⇒ String
The ID of the association.
-
#last_updated_at ⇒ Time
The date and time that the association was last updated, in ISO-8601 format.
-
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled for the service network VPC association.
-
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
-
#service_network_id ⇒ String
The ID of the service network.
-
#service_network_name ⇒ String
The name of the service network.
-
#status ⇒ String
The status.
-
#vpc_id ⇒ String
The ID of the VPC.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the association was created, in ISO-8601 format.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The account that created the association.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#dns_options ⇒ Types::DnsOptions
The DNS options for the service network VPC association.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the association.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The date and time that the association was last updated, in ISO-8601 format.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled for the service network VPC association.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#service_network_arn ⇒ String
The Amazon Resource Name (ARN) of the service network.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#service_network_id ⇒ String
The ID of the service network.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#service_network_name ⇒ String
The name of the service network.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC.
4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 4953 class ServiceNetworkVpcAssociationSummary < Struct.new( :id, :arn, :status, :created_by, :created_at, :service_network_id, :service_network_name, :service_network_arn, :private_dns_enabled, :dns_options, :vpc_id, :last_updated_at) SENSITIVE = [] include Aws::Structure end |