Class: Aws::VPCLattice::Types::UpdateResourceConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_association_to_shareable_service_networkBoolean

Indicates whether to add the resource configuration to service networks that are shared with other accounts.

Returns:

  • (Boolean)


5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-vpclattice/types.rb', line 5688

class UpdateResourceConfigurationResponse < Struct.new(
  :id,
  :name,
  :arn,
  :resource_gateway_id,
  :resource_configuration_group_id,
  :type,
  :port_ranges,
  :allow_association_to_shareable_service_network,
  :protocol,
  :status,
  :resource_configuration_definition)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the resource configuration.

Returns:

  • (String)


5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-vpclattice/types.rb', line 5688

class UpdateResourceConfigurationResponse < Struct.new(
  :id,
  :name,
  :arn,
  :resource_gateway_id,
  :resource_configuration_group_id,
  :type,
  :port_ranges,
  :allow_association_to_shareable_service_network,
  :protocol,
  :status,
  :resource_configuration_definition)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the resource configuration.

Returns:

  • (String)


5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-vpclattice/types.rb', line 5688

class UpdateResourceConfigurationResponse < Struct.new(
  :id,
  :name,
  :arn,
  :resource_gateway_id,
  :resource_configuration_group_id,
  :type,
  :port_ranges,
  :allow_association_to_shareable_service_network,
  :protocol,
  :status,
  :resource_configuration_definition)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the resource configuration.

Returns:

  • (String)


5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-vpclattice/types.rb', line 5688

class UpdateResourceConfigurationResponse < Struct.new(
  :id,
  :name,
  :arn,
  :resource_gateway_id,
  :resource_configuration_group_id,
  :type,
  :port_ranges,
  :allow_association_to_shareable_service_network,
  :protocol,
  :status,
  :resource_configuration_definition)
  SENSITIVE = []
  include Aws::Structure
end

#port_rangesArray<String>

The TCP port ranges that a consumer can use to access a resource configuration. You can separate port ranges with a comma. Example: 1-65535 or 1,2,22-30

Returns:

  • (Array<String>)


5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-vpclattice/types.rb', line 5688

class UpdateResourceConfigurationResponse < Struct.new(
  :id,
  :name,
  :arn,
  :resource_gateway_id,
  :resource_configuration_group_id,
  :type,
  :port_ranges,
  :allow_association_to_shareable_service_network,
  :protocol,
  :status,
  :resource_configuration_definition)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The TCP protocol accepted by the specified resource configuration.

Returns:

  • (String)


5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-vpclattice/types.rb', line 5688

class UpdateResourceConfigurationResponse < Struct.new(
  :id,
  :name,
  :arn,
  :resource_gateway_id,
  :resource_configuration_group_id,
  :type,
  :port_ranges,
  :allow_association_to_shareable_service_network,
  :protocol,
  :status,
  :resource_configuration_definition)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_definitionTypes::ResourceConfigurationDefinition

The resource configuration.



5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-vpclattice/types.rb', line 5688

class UpdateResourceConfigurationResponse < Struct.new(
  :id,
  :name,
  :arn,
  :resource_gateway_id,
  :resource_configuration_group_id,
  :type,
  :port_ranges,
  :allow_association_to_shareable_service_network,
  :protocol,
  :status,
  :resource_configuration_definition)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_group_idString

The ID of the group resource configuration.

Returns:

  • (String)


5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-vpclattice/types.rb', line 5688

class UpdateResourceConfigurationResponse < Struct.new(
  :id,
  :name,
  :arn,
  :resource_gateway_id,
  :resource_configuration_group_id,
  :type,
  :port_ranges,
  :allow_association_to_shareable_service_network,
  :protocol,
  :status,
  :resource_configuration_definition)
  SENSITIVE = []
  include Aws::Structure
end

#resource_gateway_idString

The ID of the resource gateway associated with the resource configuration.

Returns:

  • (String)


5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-vpclattice/types.rb', line 5688

class UpdateResourceConfigurationResponse < Struct.new(
  :id,
  :name,
  :arn,
  :resource_gateway_id,
  :resource_configuration_group_id,
  :type,
  :port_ranges,
  :allow_association_to_shareable_service_network,
  :protocol,
  :status,
  :resource_configuration_definition)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the resource configuration.

Returns:

  • (String)


5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-vpclattice/types.rb', line 5688

class UpdateResourceConfigurationResponse < Struct.new(
  :id,
  :name,
  :arn,
  :resource_gateway_id,
  :resource_configuration_group_id,
  :type,
  :port_ranges,
  :allow_association_to_shareable_service_network,
  :protocol,
  :status,
  :resource_configuration_definition)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of resource configuration.

  • ‘SINGLE` - A single resource.

  • ‘GROUP` - A group of resources.

  • ‘CHILD` - A single resource that is part of a group resource configuration.

  • ‘ARN` - An Amazon Web Services resource.

Returns:

  • (String)


5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-vpclattice/types.rb', line 5688

class UpdateResourceConfigurationResponse < Struct.new(
  :id,
  :name,
  :arn,
  :resource_gateway_id,
  :resource_configuration_group_id,
  :type,
  :port_ranges,
  :allow_association_to_shareable_service_network,
  :protocol,
  :status,
  :resource_configuration_definition)
  SENSITIVE = []
  include Aws::Structure
end