Class: Aws::VPCLattice::Types::UpdateServiceNetworkVpcAssociationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The account that created the association.

Returns:

  • (String)


5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#dns_optionsTypes::DnsOptions

DNS options for the service network VPC association.

Returns:



5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the association.

Returns:

  • (String)


5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_enabledBoolean

Indicates if private DNS is enabled for the VPC association.

Returns:

  • (Boolean)


5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The IDs of the security groups.

Returns:

  • (Array<String>)


5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status. You can retry the operation if the status is DELETE_FAILED. However, if you retry it while the status is DELETE_IN_PROGRESS, there is no change in the status.

Returns:

  • (String)


5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids,
  :private_dns_enabled,
  :dns_options)
  SENSITIVE = []
  include Aws::Structure
end