Class: Aws::VPCLattice::Types::UpdateServiceNetworkVpcAssociationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::UpdateServiceNetworkVpcAssociationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
-
#created_by ⇒ String
The account that created the association.
-
#dns_options ⇒ Types::DnsOptions
DNS options for the service network VPC association.
-
#id ⇒ String
The ID of the association.
-
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled for the VPC association.
-
#security_group_ids ⇒ Array<String>
The IDs of the security groups.
-
#status ⇒ String
The status.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids, :private_dns_enabled, :dns_options) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The account that created the association.
5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids, :private_dns_enabled, :dns_options) SENSITIVE = [] include Aws::Structure end |
#dns_options ⇒ Types::DnsOptions
DNS options for the service network VPC association.
5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids, :private_dns_enabled, :dns_options) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the association.
5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids, :private_dns_enabled, :dns_options) SENSITIVE = [] include Aws::Structure end |
#private_dns_enabled ⇒ Boolean
Indicates if private DNS is enabled for the VPC association.
5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids, :private_dns_enabled, :dns_options) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the security groups.
5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids, :private_dns_enabled, :dns_options) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status. You can retry the operation if the status is
DELETE_FAILED. However, if you retry it while the status is
DELETE_IN_PROGRESS, there is no change in the status.
5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5980 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids, :private_dns_enabled, :dns_options) SENSITIVE = [] include Aws::Structure end |