Class: Aws::VPCLattice::Types::UpdateServiceNetworkVpcAssociationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-vpclattice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the association.

Returns:

  • (String)


5962
5963
5964
5965
5966
5967
5968
5969
5970
# File 'lib/aws-sdk-vpclattice/types.rb', line 5962

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The account that created the association.

Returns:

  • (String)


5962
5963
5964
5965
5966
5967
5968
5969
5970
# File 'lib/aws-sdk-vpclattice/types.rb', line 5962

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the association.

Returns:

  • (String)


5962
5963
5964
5965
5966
5967
5968
5969
5970
# File 'lib/aws-sdk-vpclattice/types.rb', line 5962

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The IDs of the security groups.

Returns:

  • (Array<String>)


5962
5963
5964
5965
5966
5967
5968
5969
5970
# File 'lib/aws-sdk-vpclattice/types.rb', line 5962

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status. You can retry the operation if the status is DELETE_FAILED. However, if you retry it while the status is DELETE_IN_PROGRESS, there is no change in the status.

Returns:

  • (String)


5962
5963
5964
5965
5966
5967
5968
5969
5970
# File 'lib/aws-sdk-vpclattice/types.rb', line 5962

class UpdateServiceNetworkVpcAssociationResponse < Struct.new(
  :id,
  :arn,
  :status,
  :created_by,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end