Class: Aws::VPCLattice::Types::UpdateServiceNetworkVpcAssociationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::VPCLattice::Types::UpdateServiceNetworkVpcAssociationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-vpclattice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
-
#created_by ⇒ String
The account that created the association.
-
#id ⇒ String
The ID of the association.
-
#security_group_ids ⇒ Array<String>
The IDs of the security groups.
-
#status ⇒ String
The status.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the association.
5939 5940 5941 5942 5943 5944 5945 5946 5947 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5939 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The account that created the association.
5939 5940 5941 5942 5943 5944 5945 5946 5947 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5939 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the association.
5939 5940 5941 5942 5943 5944 5945 5946 5947 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5939 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the security groups.
5939 5940 5941 5942 5943 5944 5945 5946 5947 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5939 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status. You can retry the operation if the status is ‘DELETE_FAILED`. However, if you retry it while the status is `DELETE_IN_PROGRESS`, there is no change in the status.
5939 5940 5941 5942 5943 5944 5945 5946 5947 |
# File 'lib/aws-sdk-vpclattice/types.rb', line 5939 class UpdateServiceNetworkVpcAssociationResponse < Struct.new( :id, :arn, :status, :created_by, :security_group_ids) SENSITIVE = [] include Aws::Structure end |